SystemOrganization addCategory: #'Seaside-Development-Core'!
SystemOrganization addCategory: #'Seaside-Development-Plugins'!
SystemOrganization addCategory: #'Seaside-Development-Filter'!

!WADispatcher methodsFor: '*seaside-development' stamp: 'lr 2/10/2008 15:45'!
configurationComponent
	^ WADispatcherEditor on: self! !

!WAPackage class methodsFor: '*seaside-development' stamp: 'lr 10/23/2008 21:13'!
seasideDevelopment
	^ self new
		name: 'Seaside-Development';
		description: 'Web-based development tools and debugging support.';
		addDependency: 'Seaside-Environment';
		yourself! !

WAErrorHandler subclass: #WADebugErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADebugErrorHandler commentStamp: 'pmm 5/27/2007 21:47' prior: 0!
I am like WAErrorHandler except that I open a debugger in the image for errors and warnings (not for internal errors).!

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 11/12/2008 01:58'!
debugAndResume: anException
	self open: anException.

	"If the user closes the debugger, the process is terminated and the stack unwound.
	There was previously an #ifCurtailed: block around the #open: call above to try to
	catch the process termination so we could display a nice error page but this also
	ended up being called when the user restarted a context in the debugger.
	
	If they Proceed in the debugger, behaviour is platform-dependent. Currently, VW
	should resume the signaling context, so this method will not continue past the call
	to #open:. Squeak currently resumes the context that opened the Debugger, which
	results in the call to #open: returning."

	^ anException isResumable
		ifTrue: [ anException resume ]
		ifFalse: [ self unableToResumeResponse ]! !

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 9/19/2008 19:45'!
handleDefault: anException
	^ self debugAndResume: anException! !

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 9/14/2008 13:34'!
open: anException
	SeasidePlatformSupport openDebuggerOn: anException! !

!WADebugErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 15:35'!
unableToResumeResponse
	| content |
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Unable to proceed' ];
		render: [ :html |
			html heading level1; with: 'Unable to proceed - hit Refresh to retry'.
			html paragraph: 'Some exceptions cannot be resumed. You will usually see this page if you hit Proceed while debugging one of these exceptions. Your request was aborted but you can retry it by refreshing the page.' ].
	
	^ WAResponse new
		internalError;
		nextPutAll: content;
		yourself! !

WADebugErrorHandler subclass: #WAWalkbackErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAWalkbackErrorHandler commentStamp: 'jf 10/27/2008 22:44' prior: 0!
I am the default development error handler that displays the stack frames and adds the option to display a debugger.

I delegate the rendering to WAWalkback.

This handler uses Components and depends on having a valid Session. If an error occurs outside of the Session scope it will simply use the superclass behaviour, which should be to open a debugger.!

!WAWalkbackErrorHandler methodsFor: 'private' stamp: 'jf 12/30/2008 20:05'!
open: anException
	| answer |
	self requestContext request isXmlHttpRequest ifTrue: [ ^ super open: anException ].
	
	"If an error occurs outside the scope of a session or the part of the session where
	WACurrentRequestContext is defined, we need to catch this and just use the super
	behaviour."
	[answer := self session isNil or:
				[ self session inNewRenderLoopCall:
					(SeasidePlatformSupport walkbackClass exception: anException) ].
	answer ifTrue: [ super open: anException ] ]
		on: WARequestContextRequest
		do: [ :err | super open: anException ]! !

WADecoration subclass: #WAToolDecoration
	instanceVariableNames: 'plugins showHalos'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAToolDecoration class methodsFor: 'testing' stamp: 'lr 9/14/2008 12:54'!
canBeRoot
	^ true! !

!WAToolDecoration methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:26'!
initialize
	super initialize.
	showHalos := WAValueHolder with: false! !

!WAToolDecoration methodsFor: 'testing' stamp: 'lr 1/3/2008 13:15'!
isGlobal
	^ true! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 9/13/2008 17:14'!
plugins
	^ plugins ifNil: [ plugins := WAToolPlugin allSubclassesOn: self component for: self ]! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'jf 11/3/2008 22:28'!
renderChildOn: html
	self showHalos
		ifTrue: [ html context debugMode ].
	self renderNextOn: html.
	html context clearMode! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html
	self renderChildOn: html.
	self renderToolbarOn: html! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'lr 9/25/2008 10:40'!
renderToolbarOn: html
	html div id: 'toolbar'; with: [
		(self plugins select: [ :each | each isActive ])
			do: [ :each | html render: each ]
			separatedBy: [ html text: ' ' ] ]! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 6/5/2007 21:46'!
showHalos
	^ showHalos contents! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 4/15/2007 18:46'!
states
	^ Array with: showHalos! !

!WAToolDecoration methodsFor: 'plugin-halos' stamp: 'lr 3/24/2008 11:20'!
toggleHalos
	showHalos contents: showHalos contents not! !

!WAToolDecoration methodsFor: 'updating' stamp: 'MAD 8/29/2008 18:02'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	WADevelopmentFiles default updateRoot: anHtmlRoot! !

!WARequestHandler methodsFor: '*seaside-development' stamp: 'jf 10/7/2008 01:18'!
cloneHandler
	^ self copy! !

!WARequestHandler methodsFor: '*seaside-development' stamp: 'jf 7/21/2008 23:47'!
configurationComponent
	^ WAHandlerEditor on: self! !

WAComponent subclass: #WAHalo
	instanceVariableNames: 'root mode plugins'
	classVariableNames: 'Halos'
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAHalo class methodsFor: 'instance-creation' stamp: 'lr 5/11/2007 01:05'!
for: aComponent
	^ Halos at: aComponent ifAbsentPut: [ self new initializeOn: aComponent ]! !

!WAHalo class methodsFor: 'class initialization' stamp: 'lr 3/24/2008 11:20'!
initialize
	Halos := SeasidePlatformSupport weakDictionaryOfSize: 20! !

!WAHalo methodsFor: 'rendering' stamp: 'jf 10/21/2008 20:11'!
canHaveHalo
	^ false! !

!WAHalo methodsFor: 'initialization' stamp: 'lr 9/5/2007 11:46'!
initializeOn: aComponent
	root := aComponent.
	mode := WAValueHolder with: self modes first.
	plugins := WAHaloPlugin allSubclassesOn: self root for: self! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 12/6/2006 20:25'!
mode
	^ mode contents! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 12/6/2006 20:24'!
mode: aSymbol
	mode contents: aSymbol! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 3/26/2007 22:26'!
modes
	^ #( render: source: )! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 5/11/2007 01:06'!
plugins
	^ plugins! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'lr 5/11/2007 09:39'!
render: html
	self root renderContentOn: html! !

!WAHalo methodsFor: 'rendering' stamp: 'jf 10/7/2008 19:54'!
renderContentOn: html
	| haloHtml |
	haloHtml := self rendererClass context: html context.
	haloHtml div class: 'halo'; with: [
		haloHtml div class: 'halo-header'; with: [
			(self plugins select: [ :each | each isActive ])
				do: [ :each | html render: each ]
				separatedBy: [ html text: ' ' ] ].
		haloHtml div class: 'halo-body'; with: [
			self perform: self mode with: html ] ].
	haloHtml flush.
	html flush! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 5/11/2007 09:39'!
root
	^ root! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'obi 12/16/2008 22:52'!
source: html
	| context haloHtml |
	haloHtml := self rendererClass context: html context.
	context := haloHtml context copy.
	context clearMode.
	context visitor: nil.
	context document: (WAPrettyPrintedDocument renderer: haloHtml).
	haloHtml div
		class: 'halo-source';
		with: [ self root renderWithContext: context ].
	haloHtml flush! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 4/15/2007 18:50'!
states
	^ Array with: mode! !

WAComponent subclass: #WAHandlerEditor
	instanceVariableNames: 'handler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

WAHandlerEditor subclass: #WADispatcherComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 2/10/2008 17:19'!
dispatcher: aHandler
	handler := aHandler! !

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 10/26/2008 17:07'!
entryPoints
	"Answer a dictionary of the visible entry points."

	^ self handler entryPoints! !

!WADispatcherComponent methodsFor: 'initialization' stamp: 'jf 9/22/2008 21:08'!
initialRequest: aRequest
	"Check my relative URL, if the last entry is an application open the config editor, else open the dispatcher editor."
	
	| requestUrl baseUrl |
	super initialRequest: aRequest.
	requestUrl := aRequest url.
	baseUrl := WAUrl new
		addAllToPath: self application path;
		yourself.
	self openHandler: (self 
		lookupHandler: (baseUrl
			relativeTo: requestUrl))! !

!WADispatcherComponent methodsFor: 'initialization' stamp: 'jf 7/31/2008 15:27'!
initialize
	super initialize.
	self initializeOn: WADispatcher default! !

!WADispatcherComponent methodsFor: 'actions' stamp: 'lr 9/13/2008 16:16'!
lookupHandler: aCollection
	^ aCollection
		inject: self handler
		into: [ :requesthandler :name |
			requesthandler isDispatcher
				ifFalse: [ ^ requesthandler ]
				ifTrue: [
					requesthandler entryPoints 
						at: name
						ifAbsent: [ ^ nil ] ] ]! !

!WADispatcherComponent methodsFor: 'actions' stamp: 'lr 9/13/2008 16:16'!
openHandler: aHandler
	aHandler isNil ifTrue: [ ^ self ].
	self initializeOn: (aHandler isDispatcher
		ifFalse: [ aHandler parent ]
		ifTrue: [ aHandler ])! !

!WADispatcherComponent methodsFor: 'rendering' stamp: 'lr 2/10/2008 16:14'!
renderContentOn: html
	super renderContentOn: html.
	self renderDispatcherOn: html! !

!WADispatcherComponent methodsFor: 'rendering' stamp: 'lr 2/10/2008 17:18'!
renderDispatcherOn: html
	html table: [
		self handler isRoot
			ifFalse: [ self renderRow: self handler parent named: '..' on: html ].
		self entryPoints keysSortedSafely
			do: [ :each | self renderRow: (self handler entryPoints at: each) named: each on: html ] ]! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 1/5/2007 22:08'!
renderRow: anEntryPoint named: aString on: html
	html tableRow: [
		html tableData: [ self renderRowName: anEntryPoint named: aString on: html ].
		html tableData: [ self renderRowDescription: anEntryPoint named: aString on: html ].
		html tableData: [ self renderRowActions: anEntryPoint named: aString on: html ] ]! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 1/5/2007 22:08'!
renderRowActions: anEntryPoint named: aString on: html! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 10/28/2007 14:42'!
renderRowDescription: anEntryPoint named: aString on: html
	aString = self upDirectory
		ifFalse: [ html render: anEntryPoint description ]
		ifTrue: [ html render: 'Parent Directory' ]! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 12/27/2008 18:29'!
renderRowName: anEntryPoint named: aString on: html
	anEntryPoint isDispatcher
		ifTrue: [
			html anchor
				callback: [ self dispatcher: anEntryPoint ];
				with: [ html code: aString , '/' ] ]
		ifFalse: [
			html anchor 
				url: anEntryPoint basePath , '/'; 
				with: [ html code: aString ] ]! !

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 4/15/2007 19:54'!
states
	^ Array with: self! !

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 2/10/2008 16:19'!
upDirectory
	^ '..'! !

WADispatcherComponent subclass: #WADispatcherEditor
	instanceVariableNames: 'name type'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADispatcherEditor class methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
canBeRoot
	^ true! !

!WADispatcherEditor class methodsFor: 'accessing' stamp: 'lr 2/12/2007 23:16'!
description
	^ 'Dispatcher Editor'! !

!WADispatcherEditor class methodsFor: 'initialization' stamp: 'jf 10/26/2008 17:43'!
initialize
	(WAAdmin register: self asApplicationAt: 'config') addLibrary: WAHandlerEditorFiles! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 10/21/2008 15:41'!
addConfiguration
	(name isNil or: [ name isEmpty ])
		ifTrue: [ self inform: 'You must enter a configuration-name.' ]
		ifFalse: [ self editConfiguration: (self sharedConfiguration named: name) ]! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'jf 10/26/2008 12:24'!
addEntryPoint
	| newHandler editorCommand |
	(name isNil or: [ name isEmpty ])
		ifTrue: [ ^ self inform: 'You must enter a path-name.' ].
	newHandler :=  WAAdmin register: type at: name.
	newHandler isApplication ifTrue: [
		newHandler configuration
			removeParent: WASessionConfiguration instance;
			addParent: WARenderLoopConfiguration instance ].
	editorCommand := WAConfigureDispatcherPlugin on: newHandler for: self.
	editorCommand isActive ifTrue: [ editorCommand execute ]! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 11/28/2008 16:46'!
editConfiguration: aConfiguration
	self show: aConfiguration configurationComponent! !

!WADispatcherEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 16:13'!
entryPointClasses
	^ WAEntryPoint concreteSubclasses asSortedCollection: [ :a :b | a name < b name ]! !

!WADispatcherEditor methodsFor: 'initialization' stamp: 'lr 2/12/2007 21:01'!
initialize
	super initialize.
	type := WAApplication.
	name := String new! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 11/28/2008 16:43'!
openHandler: aHandler
	super openHandler: aHandler.
	aHandler isApplication
		ifTrue: [ self show: aHandler configurationComponent ]! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 10/21/2008 15:55'!
removeConfiguration: aConfiguration
	aConfiguration unregister! !

!WADispatcherEditor methodsFor: 'rendering-parts' stamp: 'lr 2/10/2008 17:24'!
renderAddEntryPointOn: html
	html heading level: 3; with: 'Add entry point'.
	html form: [
		html table: [
			html tableRow: [
				html tableData class: 'label'; with: 'Name: '.
				html tableData: [
					html textInput
						callback: [ :value | name := value ] ] ].
			html tableRow: [
				html tableData class: 'label'; with: 'Type: '.
				html tableData: [
					html select
						selected: type;
						list: self entryPointClasses;
						callback: [ :value | type := value ];
						labels: [ :each | each description ].
				html space.
				html submitButton
					callback: [ self addEntryPoint ];
					text: 'Add' ] ] ] ]! !

!WADispatcherEditor methodsFor: 'rendering-parts' stamp: 'lr 12/29/2008 09:59'!
renderConfigurationsOn: html
	html heading level: 2; with: 'Shared Configurations'.
	html form: [
		html unorderedList: [
			self sharedConfiguration configurations do: [ :each |
				html listItem: [
					html anchor
						callback: [ self editConfiguration: each ];
						with: each name.
					html space.
					html anchor
						callback: [ self removeConfiguration: each ];
						with: [ html html: '&times;' ] ] ] ].
		html paragraph: [
			html textInput
				callback: [ :value | name := value ].
			html submitButton
				callback: [ self addConfiguration ];
				text: 'Add' ] ]! !

!WADispatcherEditor methodsFor: 'rendering' stamp: 'lr 11/28/2008 16:46'!
renderContentOn: html
	super renderContentOn: html.
	self renderSettingsOn: html.
	html paragraph: [
		html anchor
			callback: [ self show: self handler configuration configurationComponent ];
			with: 'edit dispatcher configuration' ].
	self renderConfigurationsOn: html! !

!WADispatcherEditor methodsFor: 'rendering-parts' stamp: 'pmm 10/28/2008 16:24'!
renderDefaultEntryPointOn: html
	html heading level: 3; with: 'Default entry point'.
	html form: [
		html paragraph: [
			html select
				beOptional;
				optionalLabel: '(none)';
				list: self handler entryPoints keysSortedSafely;
				on: #defaultName of: self handler.
			html space.
			html submitButton
				text: 'Set' ] ]! !

!WADispatcherEditor methodsFor: 'rendering-rows' stamp: 'jf 8/5/2008 09:03'!
renderRowActions: anEntryPoint named: aString on: html
	aString = self upDirectory ifTrue: [ ^ nil ].
	((WADispatcherPlugin allSubclassesOn: anEntryPoint for: self)
		select: [ :each | each isActive ])
			do: [ :each | html render: each ]
			separatedBy: [ html text: ' ' ]! !

!WADispatcherEditor methodsFor: 'rendering' stamp: 'lr 2/10/2008 17:25'!
renderSettingsOn: html
	html heading level: 2; with: 'Settings'.
	self renderDefaultEntryPointOn: html.
	self renderAddEntryPointOn: html! !

!WADispatcherEditor methodsFor: 'accessing' stamp: 'lr 10/21/2008 15:50'!
sharedConfiguration
	^ WASharedConfiguration! !

WADispatcherComponent subclass: #WADispatcherViewer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADispatcherViewer class methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
canBeRoot
	^ true! !

!WADispatcherViewer class methodsFor: 'accessing' stamp: 'lr 5/9/2007 08:51'!
description
	^ 'Dispatcher Viewer'! !

!WADispatcherViewer class methodsFor: 'initialization' stamp: 'jf 10/26/2008 17:41'!
initialize
	(WAAdmin register: self asApplicationAt: 'browse') addLibrary: WAHandlerEditorFiles.
	WADispatcher default 
		defaultName: 'browse'! !

WAHandlerEditor subclass: #WAEntryPointEditor
	instanceVariableNames: 'configurationEditor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAEntryPointEditor methodsFor: 'accessing' stamp: 'jf 7/21/2008 23:44'!
children
	^ Array with: configurationEditor! !

!WAEntryPointEditor methodsFor: 'initialization' stamp: 'pmm 11/4/2008 20:51'!
initializeOn: aHandler
	super initializeOn: aHandler.
	aHandler configuration isNil ifTrue: [ ^self ].
	
	configurationEditor := aHandler configuration configurationComponent.
	configurationEditor onAnswer: [ self answer ]! !

!WAEntryPointEditor methodsFor: 'rendering' stamp: 'jf 7/21/2008 23:45'!
renderConfigurationOn: html
	handler configuration isNil ifFalse: [
		html render: configurationEditor ]! !

!WAEntryPointEditor methodsFor: 'rendering' stamp: 'jf 7/21/2008 23:46'!
renderContentOn: html
	super renderContentOn: html.
	self renderConfigurationOn: html.! !

!WAEntryPointEditor methodsFor: 'accessing' stamp: 'jf 7/21/2008 23:43'!
title
	^ super title, ' on ' , self handler basePath! !

WAHandlerEditor subclass: #WAFileHandlerEditor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAFileHandlerEditor methodsFor: 'accessing' stamp: 'jf 8/5/2008 09:26'!
basePath
	^ self handler baseUrl pathString! !

!WAFileHandlerEditor methodsFor: 'actions' stamp: 'lr 11/28/2008 16:45'!
configureLibrary: aLibrary
	self show: aLibrary configurationComponent! !

!WAFileHandlerEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 18:54'!
libraries
	^ self handler libraries asSortedCollection: [ :a :b | a name < b name ]! !

!WAFileHandlerEditor methodsFor: 'rendering' stamp: 'lr 11/28/2008 16:46'!
renderContentOn: html
	super renderContentOn: html.
	html paragraph: [
		html anchor
			callback: [ self show: self handler configuration configurationComponent ];
			with: 'edit file handler configuration' ].
	html table: [
		self libraries do: [ :each |
			html tableRow: [
				html tableData: each name.
				html tableData: [
					html anchor
						callback: [ self configureLibrary: each default ];
						with: 'configure' ] ] ] ].
	html form: [
		html submitButton
			callback: [ self answer ];
			text: 'close' ]! !

!WAHandlerEditor class methodsFor: 'instance-creation' stamp: 'lr 2/10/2008 14:55'!
on: anEntryPoint
	^ self new initializeOn: anEntryPoint! !

!WAHandlerEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 15:58'!
handler
	^ handler! !

!WAHandlerEditor methodsFor: 'initialization' stamp: 'lr 2/10/2008 15:58'!
initializeOn: aHandler
	handler := aHandler! !

!WAHandlerEditor methodsFor: 'rendering' stamp: 'lr 2/10/2008 15:37'!
renderContentOn: html
	self renderHeadingOn: html! !

!WAHandlerEditor methodsFor: 'rendering' stamp: 'lr 10/8/2008 09:13'!
renderHeadingOn: html
	html heading class: 'logo'; with: [
		html anchor
			url: (WAUrl new 
				hostname: 'www.seaside.st';
				addParameter: 'version' value: SeasidePlatformSupport versionString;
				addParameter: 'platform' value: SeasidePlatformSupport platformString;
				yourself);
			with: 'Seaside' ].
	html heading class: 'title'; with: [
		html anchor
			url: self handler baseUrl;
			with: self title ]! !

!WAHandlerEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 17:56'!
title
	^ self handler description! !

!WAHandlerEditor methodsFor: 'processing' stamp: 'jf 7/31/2008 16:11'!
updateRoot: aHtmlRoot
	super updateRoot: aHtmlRoot.
	aHtmlRoot title: self title! !

!WAHandlerEditor methodsFor: 'processing' stamp: 'lr 3/24/2008 14:24'!
updateUrl: anUrl
	| browsePath currentPath |
	super updateUrl: anUrl.
	browsePath := self handler path.
	currentPath := self application path.
	[ browsePath notEmpty and: [ currentPath notEmpty and: [ browsePath first = currentPath first ] ] ] whileTrue: [
		browsePath removeFirst.
		currentPath removeFirst ].
	browsePath do: [ :each | anUrl addToPath: each ]! !

WAComponent subclass: #WAStringLibraryEditor
	instanceVariableNames: 'library'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

WAStringLibraryEditor subclass: #WAFileLibraryEditor
	instanceVariableNames: 'renamingFile newName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/31/2008 15:21'!
renderAddFileOn: html
	html form multipart; with: [
	 	html div: [
			html text: 'Add File: '.
			html fileUpload on: #addFile of: self library.
			html space.
			html submitButton text: 'Add' ] ]! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:08'!
renderContentOn: html
	self renderHeadingsOn: html.
	self renderAddFileOn: html.
	self renderFilesOn: html.
	self renderWriteToDiskOn: html.
	self renderDoneOn: html! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFile: fileName on: html
	html tableData: [
		html anchor
			class: 'download';
			url: (self urlFor: fileName);
			with: fileName ].
	html tableData: [
		html anchor
			callback: [ self library removeFile: fileName ];
			with: 'remove'.
		html space.
		html anchor
			callback: [ renamingFile := fileName ];
			with: 'rename' ]! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFilesOn: html
	html table: [
		self library filenames asSortedCollection do: [ :each |
			html tableRow: [
				renamingFile = each
					ifTrue: [ self renderRenameFormForFile: each on: html ]
					ifFalse: [ self renderFile: each on: html ] ] ] ]! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderRenameFormForFile: fileName on: html
	html tableData colSpan: 2; with: [
		html form: [
			html textInput
				value: fileName;
				callback: [ :value | newName := value ].
			html submitButton
				callback: [
					self library renameFile: fileName to: newName.
					renamingFile := nil ];
			 	text: 'rename'.
			html cancelButton
				callback: [ renamingFile := nil ];
				text: 'cancel' ] ]! !

!WAFileLibraryEditor methodsFor: 'path' stamp: 'pmm 8/17/2007 07:00'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot title: self library name! !

!WAStringLibraryEditor methodsFor: 'accessing' stamp: 'lr 2/18/2007 12:36'!
library
	^ library! !

!WAStringLibraryEditor methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
library: aLibrary
	library := aLibrary! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:07'!
renderContentOn: html
	self renderHeadingsOn: html.
	self renderFilesOn: html.
	self renderWriteToDiskOn: html.
	self renderDoneOn: html! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'lr 2/18/2007 12:36'!
renderDoneOn: html
	html form: [
		html submitButton
			callback: [ self answer ];
			text: 'close' ]! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFilesOn: html
	html unorderedList: [
		self library filenames
			do: [:each |
				html listItem: [
					html anchor
					class: 'download';
						url: (self urlFor: each);
						with: each ] ] ]! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:12'!
renderHeadingsOn: html
	html heading: self library name! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:21'!
renderWriteToDiskOn: html
	html form: [
		html submitButton
			callback: [ self library deployFiles ];
			title: 'write all the files to disk';
			text: 'write to disk' ]! !

!WAStringLibraryEditor methodsFor: 'private' stamp: 'pmm 5/23/2007 22:28'!
urlFor: aFilename
	^ self library urlForFile: aFilename! !

WAComponent subclass: #WATool
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WATool commentStamp: 'pmm 10/11/2008 18:58' prior: 0!
A WATool is the common base class for tools called from the development tool bar. Is doesn't do anything but including WADevelopmentFiles.!

WATool subclass: #WADeprecation
	instanceVariableNames: 'table filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADeprecation class methodsFor: 'instance-creation' stamp: 'obi 10/8/2008 20:21'!
on: filter
	^self new filter: filter; yourself! !

!WADeprecation methodsFor: 'private' stamp: 'lr 12/30/2008 15:36'!
buildTable
	^ WATableReport new
		rowPeriod: 1;
		rowColors: #( '#eee' 'white' );
		rows: self notifications;
		columns: (Array
			with: (WAReportColumn selector: #messageText title: 'Deprecated')
			with: (WAReportColumn selector: #details title: 'Details'))
		yourself! !

!WADeprecation methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:37'!
children
	^ Array with: self table! !

!WADeprecation methodsFor: 'accessing' stamp: 'obi 10/8/2008 20:20'!
filter: aFilter
	filter := aFilter! !

!WADeprecation methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:37'!
notifications
	^ filter notifications! !

!WADeprecation methodsFor: 'rendering' stamp: 'pmm 10/11/2008 18:52'!
renderContentOn: html
	html div
		class: 'tool';
		with: [
			html render: self table.
			html anchor
				callback: [ self resetDeprecationWarnings ];
				with: 'Reset deprecation warnings' ]
	! !

!WADeprecation methodsFor: 'actions' stamp: 'pmm 10/11/2008 18:30'!
resetDeprecationWarnings
	filter reset.
	self answer! !

!WADeprecation methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:37'!
table
	^ table ifNil: [ table := self buildTable ]! !

WATool subclass: #WAPluggableTool
	instanceVariableNames: 'component'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAPluggableTool commentStamp: 'pmm 11/14/2008 22:28' prior: 0!
A WAPluggableTool is a wrapper component around tools that can't be made subclasses of WATool. WATool is only really needed to provide the icon image.

Instance Variables
	component:		<WAComponent>

component
	- the component to render
!

!WAPluggableTool class methodsFor: 'instance-creation' stamp: 'pmm 11/14/2008 22:25'!
on: aComponent
	^self new
		initializeWith: aComponent;
		yourself! !

!WAPluggableTool methodsFor: 'accessing' stamp: 'pmm 11/14/2008 22:24'!
children
	^Array with: component! !

!WAPluggableTool methodsFor: 'initialization' stamp: 'pmm 11/14/2008 22:25'!
initializeWith: aComponent
	component := aComponent! !

!WATool methodsFor: 'updating' stamp: 'pmm 10/11/2008 18:53'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	WADevelopmentFiles default updateRoot: anHtmlRoot! !

WAComponent subclass: #WAUserConfigurationEditor
	instanceVariableNames: 'configuration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

WAUserConfigurationEditor class
	instanceVariableNames: 'displayAdvancedAttributes'!

WAUserConfigurationEditor class
	instanceVariableNames: 'displayAdvancedAttributes'!

!WAUserConfigurationEditor class methodsFor: 'accessing' stamp: 'lr 1/2/2009 21:02'!
displayAdvancedAttributes
	"Answer if the advanced properties should be displayed or not."

	^ displayAdvancedAttributes ifNil: [ false ]! !

!WAUserConfigurationEditor class methodsFor: 'accessing' stamp: 'lr 1/2/2009 21:02'!
displayAdvancedAttributes: aBoolean
	displayAdvancedAttributes := aBoolean! !

!WAUserConfigurationEditor class methodsFor: 'instance-creation' stamp: 'jf 7/21/2008 18:04'!
on: aUserConfiguration
	^ self new initializeOn: aUserConfiguration
	! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'jf 1/1/2009 22:43'!
clearAttribute: anAttribute
	self configuration removeExpressionAt: anAttribute key! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'lr 2/12/2007 22:17'!
close
	self answer! !

!WAUserConfigurationEditor methodsFor: 'accessing' stamp: 'jf 7/21/2008 18:05'!
configuration
	^ configuration! !

!WAUserConfigurationEditor methodsFor: 'attributes' stamp: 'lr 1/2/2009 21:02'!
groupedAttributes
	| groups attributes |
	groups := Dictionary new.
	attributes := SortedCollection sortBlock: [ :a :b | a key <= b key].
	self configuration allAttributes valuesDo: [ :each |
		(each isAdvanced not or: [ each isAdvanced and: [ self class displayAdvancedAttributes ] ]) ifTrue: [
			(groups at: each group ifAbsentPut: [ SortedCollection sortBlock: [:a :b | a key <= b key ] ] )
				add: each ] ].
	groups associationsDo: [ :associaction | attributes add: associaction ].
	^ attributes! !

!WAUserConfigurationEditor methodsFor: 'attributes' stamp: 'jf 1/1/2009 22:46'!
hasLocalValueForAttribute: anAttribute
	self configuration expressionAt: anAttribute key ifAbsent: [^ false].
	^ true! !

!WAUserConfigurationEditor methodsFor: 'attributes' stamp: 'jf 1/1/2009 23:34'!
inheritedValueAndSourceAt: aSymbol do: aBlock
	self configuration ancestorsDo: [ :each |
		each expressionAt: aSymbol ifPresent: [ :exp |
			^ aBlock
				value: (each at: aSymbol)
				value: each ]]! !

!WAUserConfigurationEditor methodsFor: 'initialization' stamp: 'lr 8/30/2008 15:50'!
initializeOn: aUserConfiguration
	WASystemConfiguration clearAllDescriptions.
	configuration := aUserConfiguration! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'jf 1/1/2009 22:42'!
modifyCollectionAttribute: anAttribute
	self configuration at: anAttribute key addAll: #() removeAll: #()! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'jf 1/1/2009 22:39'!
overrideAttribute: anAttribute
	self configuration
		takeValue: (self configuration at: anAttribute key)
		forAttribute: anAttribute! !

!WAUserConfigurationEditor methodsFor: 'accessing' stamp: 'lr 8/30/2008 15:25'!
parents
	^ self configuration parents! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'jf 7/31/2008 14:42'!
potentialParents
	^ ((WASystemConfiguration allSubclasses collect: [ :each | each instance ]),
		WASharedConfiguration configurations)
		select: [ :each | 
			(self configuration canAddParent: each)
				and: [ (self configuration inheritsFrom: each) not ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'lr 1/2/2009 21:02'!
renderAdvancedModeOn: html
	html paragraph: [
		html anchor
			callback: [ self toggleAdvancedAttributes ];
			with: (self class displayAdvancedAttributes
				ifTrue: [ 'Hide Advanced Attributes' ]
				ifFalse: [ 'Display Advanced Attributes ']) ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'lr 8/30/2008 15:25'!
renderAncestryListOn: html 
	self configuration parents isEmpty ifTrue: [ ^ self ].
	html unorderedList: 
		[ self parents do: 
			[ :each | 
			self 
				renderParent: each
				on: html ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'jf 7/21/2008 18:30'!
renderAncestryOn: html
	html heading level: 2; with: 'Ancestry'.
	self renderParentSelectorOn: html.
	self renderAncestryListOn: html! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'jf 1/1/2009 23:31'!
renderAttribute: anAttribute on: html
	html tableRow: [
		html tableHeading: [
			html label
				title: anAttribute comment;
				with: anAttribute label ].
		html tableData: [
			(self valueForAttribute: anAttribute) isNil
				ifTrue: [ self renderUnspecifiedAttribute: anAttribute on: html ]
				ifFalse: [
					(self hasLocalValueForAttribute: anAttribute)
						ifTrue: [ self renderOverridenAttribute: anAttribute on: html ]
						ifFalse: [ self renderInheritedAttribute: anAttribute on: html ] ] ].
		self renderInheritanceForAttribute: anAttribute on: html ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'lr 1/2/2009 20:58'!
renderAttributesOn: html
	html heading level: 2; with: 'Configuration'.
	self renderAdvancedModeOn: html.
	html table: [
		self groupedAttributes do: [ :association |
			html tableRow: [
				html tableData
					colSpan: 3;
					with: [ html heading level3; with: (self labelForSelector: association key) ] ].
				association value 
					do: [ :attribute | self renderAttribute: attribute on: html ] ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'pmm 11/14/2008 21:33'!
renderButtonsOn: html
	html paragraph: [
		html break.
		html submitButton on: #save of: self.
		html submitButton on: #close of: self ]! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'lr 10/21/2008 15:49'!
renderContentOn: html
	self configuration isShared
		ifTrue: [ html heading: self configuration name ].
	html form: [
		self renderFormOn: html.
		self renderButtonsOn: html ]! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFormButtonsOn: html
	html submitButton on: #save of: self.
	html submitButton on: #done of: self! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'lr 2/12/2007 22:25'!
renderFormOn: html
	self renderAncestryOn: html.
	self renderAttributesOn: html! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'jf 1/1/2009 23:27'!
renderInheritanceForAttribute: anAttribute on: html
	html tableData: [
		| wasInherited |
		wasInherited := false.
		self inheritedValueAndSourceAt: anAttribute key do: [ :value :source |
			wasInherited ifFalse: [
				(self hasLocalValueForAttribute: anAttribute)
					ifTrue: [
						html anchor
							onClick: 'return submitForm(this)';
							title: 'revert to ' , value printString , ', overriden from ', source name;
							callback: [ self clearAttribute: anAttribute ]; 
							with: 'revert' ]
					ifFalse: [
						html anchor
							onClick: 'return submitForm(this)';
							title: 'inherited from ', source name;
							callback: [ self overrideAttribute: anAttribute ]; 
							with: 'override'.
						(anAttribute isKindOf: WACollectionAttribute) ifTrue: [
							html text: ' '.
							html anchor
								onClick: 'return submitForm(this)';
								callback: [ self modifyCollectionAttribute: anAttribute ];
								with: 'modify' ] ].
			wasInherited := true ] ].
		wasInherited ifFalse: [
			(self hasLocalValueForAttribute: anAttribute)
				ifTrue: [
					html anchor
						onClick: 'return submitForm(this)';
						callback: [ self clearAttribute: anAttribute ];
						with: 'clear' ]
				ifFalse: [
					anAttribute default isNil
						ifTrue: [
							html span
								class: 'unspecified';
								with: '(unspecified)' ]
						ifFalse: [
							html anchor
								onClick: 'return submitForm(this)';
								title: 'inherited from attribute default';
								callback: [ self overrideAttribute: anAttribute ]; 
								with: 'override'.
							(anAttribute isKindOf: WACollectionAttribute) ifTrue: [
								html text: ' '.
								html anchor
									onClick: 'return submitForm(this)';
									callback: [ self modifyCollectionAttribute: anAttribute ];
									with: 'modify' ] ] ] ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'jf 1/1/2009 23:33'!
renderInheritedAttribute: anAttribute on: html 
	html text: (self valueForAttribute: anAttribute) printString! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'avi 3/23/2004 12:34'!
renderOverridenAttribute: anAttribute on: html
	anAttribute accept: self with: html! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'lr 12/29/2008 10:32'!
renderParent: aConfiguration on: html 
	html listItem: [
		aConfiguration isShared
			ifTrue: [ 
				html anchor
					onClick: 'return submitForm(this)';
					callback: [ self show: aConfiguration configurationComponent ];
					with: aConfiguration name ]
			ifFalse: [ html text: aConfiguration name ].
		html space.
		html anchor
			onClick: 'return submitForm(this)';
			callback: [ self configuration moveParentUp: aConfiguration ];
			with: [ html html: '&uarr;' ].
		html space.
		html anchor
			onClick: 'return submitForm(this)';
			callback: [ self configuration moveParentDown:aConfiguration ];
			with: [ html html: '&darr;' ].
		html space.
		html anchor
			onClick: 'return submitForm(this)';
			callback: [ self configuration removeParent: aConfiguration ];
			with: [ html html: '&times;' ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'pmm 11/14/2008 21:23'!
renderParentSelectorOn: html 
	| selectedParent parents |
	parents := self potentialParents.
	parents isEmpty ifTrue: [ ^self ].
	
	html paragraph: [
		html text: 'Add Parent: '.
		selectedParent := WAValueHolder new.
		html select
			selected: nil;
			list: parents;
			labels: [ :each | each name ];
			callback: [ :value | selectedParent contents: value ].
		html space.
		html submitButton
			callback: [ self configuration addParent: selectedParent contents ];
			text: 'Add' ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'avi 3/23/2004 12:35'!
renderUnspecifiedAttribute: anAttribute on: html
	anAttribute accept: self with: html! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'avi 3/23/2004 14:36'!
save! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'lr 1/2/2009 21:02'!
toggleAdvancedAttributes
	self class displayAdvancedAttributes: self class displayAdvancedAttributes not! !

!WAUserConfigurationEditor methodsFor: 'attributes' stamp: 'jf 1/1/2009 23:31'!
valueForAttribute: anAttribute
	^ self configuration at: anAttribute key! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 1/1/2009 23:32'!
visitBooleanAttribute: anAttribute with: html 
	html select
		list: (Array with: true with: false);
		selected: (self valueForAttribute: anAttribute);
		callback: [ :value | self configuration takeValue: value forAttribute: anAttribute];
		labels: [ :bool | bool ifTrue: [ 'true' ] ifFalse: [ 'false' ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'a 9/5/2008 20:25'!
visitCollectionAttribute: anAttribute with: html
	| expression |
	expression := self configuration 
		expressionAt: anAttribute key
		ifAbsent: [ ^ self ].
	(expression isKindOf: WAValueExpression)
		ifTrue: [ 
			html multiSelect
				list: anAttribute options;
				on: #value of: expression ]
		ifFalse: [
			html multiSelect
				title: 'removals';
				list: anAttribute options;
				on: #removals of: expression.
			html multiSelect
				title: 'additions';
				list: anAttribute options;
				on: #additions of: expression ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'lr 1/2/2009 21:07'!
visitListAttribute: anAttribute with: html
	| options value |
	options := anAttribute options asArray.
	value := self valueForAttribute: anAttribute.
	(value isNil or: [ options includes: value ])
		ifFalse: [ options := (Array with: value) , (options) ].
	html select
		beOptional;
		list: options;
		selected: value;
		optionalLabel: '(none)';
		callback: [ :each | self configuration takeValue: each forAttribute: anAttribute ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 1/1/2009 23:32'!
visitNumberAttribute: anAttribute with: html 
	html textInput
		size: 5;
		callback: [ :value | self configuration takeValueFromString: value forAttribute: anAttribute ];
		value: (self valueForAttribute: anAttribute)! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 7/19/2008 20:44'!
visitPasswordAttribute: anAttribute with: html 
	html passwordInput 
		callback: [ :value | self configuration takeValueFromString: value forAttribute: anAttribute ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 1/1/2009 23:32'!
visitStringAttribute: anAttribute with: html 
	html textInput
		callback: [ :value | self configuration takeValueFromString: value forAttribute: anAttribute ];
		value: (self valueForAttribute: anAttribute)! !

WARequestFilter subclass: #WADeprecatedToolFilter
	instanceVariableNames: 'notifications'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Filter'!

!WADeprecatedToolFilter methodsFor: 'actions' stamp: 'lr 12/30/2008 15:41'!
deprecated: aNotification
	"Adds a deprecated warning aNotification to the receiver. Remove old deprecation warnings that have the same message and detail text."

	notifications := notifications reject: [ :each | 
		(each messageText = aNotification messageText)
			and: [ each details = aNotification details ] ].
	notifications add: aNotification.
	aNotification resume! !

!WADeprecatedToolFilter methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:25'!
initialize
	super initialize.
	self reset! !

!WADeprecatedToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:13'!
notifications
	^ notifications! !

!WADeprecatedToolFilter methodsFor: 'actions' stamp: 'lr 9/25/2008 15:12'!
reset
	notifications := OrderedCollection new! !

!WADeprecatedToolFilter methodsFor: 'processing' stamp: 'lr 9/25/2008 14:24'!
responseForContext: aRequestContext
	^ [ super responseForContext: aRequestContext ]
		on: WADeprecatedApi
		do: [ :notification | self deprecated: notification ]! !

WARequestFilter subclass: #WATimingToolFilter
	instanceVariableNames: 'startTime previousTiming'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Filter'!

!WATimingToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:29'!
currentTiming
	"Answer the running timing, or 0 if no value is available."

	^ startTime isNil ifTrue: [ 0 ] ifFalse: [ Time millisecondsSince: startTime ]! !

!WATimingToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:29'!
previousTiming
	"Answer the previous timing, or 0 if no value is available."

	^ previousTiming ifNil: [ 0 ]! !

!WATimingToolFilter methodsFor: 'processing' stamp: 'pmm 11/4/2008 20:17'!
responseForContext: aRequestContext
	startTime := Time millisecondClockValue.
	^ [ super responseForContext: aRequestContext ]
		ensure: [ previousTiming := self currentTiming ]! !

WASystemConfiguration subclass: #WADevelopmentConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADevelopmentConfiguration methodsFor: 'description' stamp: 'jf 9/17/2008 20:13'!
describeOn: config
	config at: #rootDecorationClasses addAll: (Array with: WAToolDecoration).
	config at: #libraries addAll: (Array with: WADevelopmentFiles).
	config at: #exceptionHandler put: WAWalkbackErrorHandler! !

!WADevelopmentConfiguration methodsFor: 'description' stamp: 'lr 9/14/2008 13:39'!
parents
	^ Array with: WARenderLoopConfiguration instance with: WAApplicationConfiguration instance! !

!WAApplication methodsFor: '*seaside-development' stamp: 'jf 10/27/2008 11:24'!
cloneHandler
	^ super cloneHandler
		clear;
		yourself! !

WALabelledFormDialog subclass: #WAViewer
	instanceVariableNames: 'presenter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAViewer class methodsFor: 'instance-creation' stamp: 'avi 3/13/2004 01:13'!
on: aPresenter
	^ self new presenter: aPresenter! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
buttons
	^ #(save)! !

!WAViewer methodsFor: 'actions' stamp: 'pmm 7/28/2007 10:27'!
compile: aString
	SeasidePlatformSupport
		compile: aString
		into: presenter class
		classified: #rendering! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
model
	^ presenter! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:13'!
presenter: aPresenter
	presenter := aPresenter! !

!WAViewer methodsFor: 'rendering' stamp: 'lr 8/30/2008 16:22'!
renderContentOn: html 
	html heading
		level3;
		with: presenter seasideString.
	super renderContentOn: html! !

!WAViewer methodsFor: 'rendering' stamp: 'pmm 7/28/2007 10:27'!
renderCssOn: html
	html textArea
		rows: 20;
		columns: 80;
		value: presenter style;
		callback: [ :css | self compile: 'style ^ ', css printString]! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
rows
	^ #(css)! !

!WAViewer methodsFor: 'actions' stamp: 'lr 10/28/2007 14:42'!
save! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:22'!
script
	^ 'self.opener.location=self.opener.location'! !

!WAEntryPoint methodsFor: '*seaside-development' stamp: 'jf 7/21/2008 23:46'!
configurationComponent
	^ WAEntryPointEditor on: self! !

WAHtmlDocument subclass: #WAPrettyPrintedDocument
	instanceVariableNames: 'html indentLevel indentCloseTags firstLine'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAPrettyPrintedDocument class methodsFor: 'instance-creation' stamp: 'avi 5/22/2004 12:40'!
renderer: aRenderer
	^ self basicNew initializeWithRenderer: aRenderer! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'pmm 8/31/2008 14:46'!
attribute: aKey with: aValue 
	aValue == false ifTrue: [ ^ self ].
	html space.
	html span
		class: (self cssClassForAttribute: aKey);
		with: aKey.
	html text: '='.
	html span
		class: 'attribute-value';
		with: [
			html text: '"'.
			(self knownRefs includes: aKey) 
				ifTrue: [
					html anchor
						url: aValue seasideString;
						with: aValue ]
				ifFalse: [
					(self knownEvents includes: aKey) 
						ifTrue: [
							html anchor
								onClick: aValue;
								with: aValue ]
						ifFalse: [
							aValue == true 
								ifTrue: [ html text: aKey ]
								ifFalse: [ html render: aValue ] ] ].
			html text: '"' ]! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 4/20/2007 22:11'!
attributes: anAttributes
	anAttributes ifNil: [ ^ self ].
	anAttributes keysAndValuesDo: [ :key :value | self attribute: key with: value ]! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 10/28/2007 14:42'!
closeTag: aString
	indentLevel := indentLevel - 1.
	indentCloseTags removeLast
		ifTrue: [ self indent ].
	html text: '</'.
	html span class: (self cssClassFor: aString); with: aString.
	html text: '>'! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:13'!
cssClassFor: aString
	^ (self knownTags includes: aString)
		ifTrue: [ 'tag-known' ]
		ifFalse: [ 'tag-unknown' ]! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:13'!
cssClassForAttribute: aString
	^ (self knownAttributes includes: aString)
		ifTrue: [ 'attribute-known' ]
		ifFalse: [ 'attribute-unknown' ]! !

!WAPrettyPrintedDocument methodsFor: 'accessing' stamp: 'lr 3/26/2007 22:28'!
document
	^ html document! !

!WAPrettyPrintedDocument methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:39'!
htmlEncoder
	^ self document htmlEncoder! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:29'!
indent
	firstLine
		ifTrue: [ firstLine := false ]
		ifFalse: [ html break ].
	indentLevel timesRepeat: [ html space: 2 ]! !

!WAPrettyPrintedDocument methodsFor: 'initialization' stamp: 'lr 11/23/2006 10:02'!
initializeWithRenderer: aRenderer
	html := aRenderer.
	indentCloseTags := OrderedCollection with: false.
	indentLevel := 0.
	firstLine := true! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 22:05'!
knownAttributes
	^ #('abbr' 'accept' 'accept' 'accesskey' 'action' 'align' 'alink' 'alt' 'archive' 'axis' 'background' 'bgcolor' 'bgproperties' 'border' 'cellpadding' 'cellspacing' 'char' 'charoff' 'charset' 'charset' 'checked' 'cite' 'class' 'classid' 'clear' 'code' 'codebase' 'codetype' 'color' 'cols' 'colspan' 'compact' 'content' 'coords' 'data' 'datetime' 'declare' 'defer' 'dir' 'direction' 'disabled' 'encoding' 'enctype' 'equiv' 'face' 'for' 'frame' 'frameborder' 'framespacing' 'gutter' 'headers' 'height' 'href' 'hreflang' 'hspace' 'http' 'id' 'ismap' 'label' 'lang' 'leftmargin' 'link' 'longdesc' 'loop' 'lowsrc' 'marginheight' 'marginwidth' 'maxlength' 'media' 'method' 'methods' 'multiple' 'name' 'nohref' 'noresize' 'noshade' 'nowrap' 'object' 'onabort' 'onblur' 'onchange' 'onclick' 'ondblclick' 'onerror' 'onfocus' 'onkeydown' 'onkeypress' 'onkeyup' 'onload' 'onmousedown' 'onmousemove' 'onmouseout' 'onmouseover' 'onmouseup' 'onreset' 'onselect' 'onsubmit' 'onunload' 'prompt' 'readonly' 'rel' 'rev' 'rows' 'rowspan' 'rules' 'scheme' 'scope' 'scrolling' 'selected' 'shape' 'size' 'span' 'src' 'standby' 'style' 'summary' 'tabindex' 'target' 'text' 'title' 'type' 'urn' 'usemap' 'valign' 'value' 'valuetype' 'version' 'vlink' 'vspace' 'width' 'wrap' 'xml:lang' 'xmlns')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 5/11/2007 11:13'!
knownEvents
	^ #('onabort' 'onblur' 'onchange' 'onclick' 'ondblclick' 'onerror' 'onfocus' 'onkeydown' 'onkeypress' 'onkeyup' 'onload' 'onmousedown' 'onmousemove' 'onmouseout' 'onmouseover' 'onmouseup' 'onreset' 'onselect' 'onsubmit' 'onunload')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 22:11'!
knownRefs
	^ #('action' 'cite' 'classid' 'codebase' 'data' 'href' 'longdesc' 'profile' 'src' 'usemap')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 21:14'!
knownTags
	^ #('a' 'abbr' 'acronym' 'address' 'area' 'b' 'base' 'bdo' 'big' 'blockquote' 'body' 'br' 'button' 'caption' 'cite' 'code' 'col' 'colgroup' 'dd' 'del' 'dfn' 'div' 'dl' 'dt' 'em' 'fieldset' 'form' 'h1' 'h2' 'h3' 'h4' 'h5' 'h6' 'head' 'hr' 'html' 'i' 'img' 'input' 'ins' 'ismap' 'kbd' 'label' 'legend' 'li' 'link' 'map' 'meta' 'noscript' 'object' 'ol' 'optgroup' 'option' 'p' 'param' 'pre' 'q' 'rb' 'rbc' 'rp' 'rt' 'rtc' 'ruby' 'samp' 'script' 'select' 'small' 'span' 'strong' 'style' 'sub' 'sup' 'table' 'tbody' 'td' 'textarea' 'tfoot' 'th' 'thead' 'title' 'tr' 'tt' 'ul' 'var')! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:39'!
nextPut: aCharacter
	self htmlEncoder nextPut: aCharacter! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:39'!
nextPutAll: aString
	self htmlEncoder nextPutAll: aString! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 10/28/2007 14:42'!
openTag: aString attributes: anAttributes closed: aBoolean
	self indent.
	html text: '<'.
	html span
		class: (self cssClassFor: aString);
		with: aString.
	self attributes: anAttributes.
	aBoolean
		ifTrue: [ html text: '/' ].
	html text: '>'.
	aBoolean
		ifFalse: [ indentLevel := indentLevel + 1 ].
	indentCloseTags removeLast; addLast: true; addLast: aBoolean! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:40'!
print: anObject
	self document print: anObject! !

WAFileLibrary subclass: #WADevelopmentFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADevelopmentFiles commentStamp: 'jf 10/6/2008 21:27' prior: 0!
CSS and images used by the web-based development tools.

The icons are from the Tango Desktop Project (tango.freedesktop.org), they are licensed under the Creative Commons Attribution Share-Alike license.
!

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:58'!
codebrowserPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 9 22 18 55 41 59 82 2 72 0 0 1 203 73 68 65 84 56 203 165 147 77 104 19 65 20 199 127 51 221 163 72 22 34 45 226 177 224 41 160 88 43 1 15 130 21 132 120 236 69 208 182 39 175 165 23 21 60 138 32 197 32 245 34 126 128 154 22 138 49 189 91 26 17 77 92 16 237 193 98 211 141 27 76 253 192 213 108 235 16 21 90 145 205 120 48 67 179 109 106 43 190 203 255 13 204 251 207 111 102 222 131 255 12 97 146 226 93 250 128 25 224 216 86 122 120 136 188 169 147 0 151 71 47 157 1 102 14 30 119 216 142 182 18 88 77 189 1 240 237 249 57 182 163 87 79 74 221 172 59 45 141 211 222 84 64 89 21 88 221 147 167 172 10 252 232 122 216 86 95 76 75 6 199 138 28 233 31 6 24 55 4 196 227 113 196 137 165 63 139 125 77 101 77 125 223 39 127 79 50 116 237 25 31 158 140 51 183 16 132 64 135 213 122 31 165 20 245 122 125 195 75 7 65 128 155 73 173 21 123 203 124 45 77 117 0 61 17 3 219 182 177 109 59 82 236 251 62 110 38 197 224 88 145 197 199 25 94 149 151 81 165 28 64 207 200 100 99 246 175 4 230 228 129 116 129 197 124 134 185 183 10 85 202 241 115 255 69 206 159 189 48 11 136 77 9 180 214 20 210 189 12 92 121 138 55 125 135 202 231 239 168 249 7 188 239 26 166 179 205 55 70 8 180 214 100 179 89 126 201 67 204 59 14 239 62 213 89 122 61 5 189 105 118 173 172 0 218 52 161 110 75 16 134 33 187 63 166 121 244 165 155 251 185 28 221 242 37 59 251 110 145 76 38 113 93 151 55 149 5 140 139 92 79 80 173 86 241 60 143 145 201 6 71 59 43 172 238 72 16 30 24 37 145 72 96 89 22 150 101 69 186 120 3 65 44 22 67 107 77 173 86 67 107 141 148 18 173 53 66 8 132 16 173 219 27 17 3 165 20 142 227 108 58 117 198 100 125 24 131 137 155 183 175 159 250 135 41 158 48 201 111 90 157 232 152 121 9 252 18 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 19:44'!
configPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 4 11 55 32 209 169 238 103 0 0 0 29 116 69 88 116 67 111 109 109 101 110 116 0 67 114 101 97 116 101 100 32 119 105 116 104 32 84 104 101 32 71 73 77 80 239 100 37 110 0 0 1 217 73 68 65 84 56 203 197 147 77 107 19 97 20 133 159 105 107 131 52 157 52 35 161 38 67 55 129 198 221 132 100 66 72 138 88 117 37 53 89 137 8 21 4 33 100 254 65 17 92 117 33 136 43 17 55 45 253 3 165 45 8 67 178 81 12 88 65 145 188 249 152 162 130 219 36 148 137 52 37 89 180 136 31 113 97 103 72 219 116 213 133 119 117 121 207 229 112 239 57 231 133 115 150 116 22 240 244 217 147 190 211 63 90 122 124 230 220 152 211 220 189 119 39 163 235 113 19 64 136 74 22 32 159 51 88 93 91 57 134 157 36 115 9 116 61 110 230 115 6 150 101 1 152 161 160 74 203 110 16 10 170 160 99 166 146 105 52 77 3 232 15 146 140 13 178 89 150 197 165 105 63 183 179 11 238 91 44 17 37 70 212 197 79 214 168 211 248 21 191 248 211 255 189 24 185 50 75 171 209 98 251 221 118 175 109 183 61 59 214 78 111 202 55 229 153 240 78 80 42 149 16 162 146 253 242 249 235 183 99 27 56 130 133 130 42 0 181 90 173 103 219 223 95 9 81 221 84 20 229 170 36 141 62 92 200 220 10 56 231 232 122 220 213 98 196 97 202 231 12 98 137 127 171 250 124 62 185 217 108 110 110 172 111 153 157 78 231 189 44 123 3 206 57 249 156 49 220 133 213 181 21 66 65 149 88 34 202 193 193 225 225 220 92 122 9 32 28 14 27 221 110 183 7 200 213 114 157 194 110 241 180 6 111 94 191 93 246 43 126 49 57 233 93 188 113 237 38 63 127 253 184 208 110 183 3 145 200 236 3 73 226 242 252 245 121 121 220 51 78 69 84 16 162 146 125 241 252 229 253 161 54 166 146 105 90 118 3 117 70 69 157 81 47 30 65 178 51 147 74 166 1 204 141 245 45 215 198 145 193 117 52 77 99 207 222 167 96 22 169 150 235 0 84 203 117 10 102 145 61 123 223 201 193 112 13 142 84 237 187 73 212 49 51 211 25 10 187 69 39 153 230 199 79 31 78 37 241 220 127 225 255 215 95 179 89 175 43 2 12 187 45 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'pmm 1/1/2009 19:14'!
deprecatedPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 214 2 16 14 39 45 183 238 146 119 0 0 1 232 73 68 65 84 56 203 149 147 193 74 27 97 20 133 191 59 153 206 52 137 51 131 16 153 74 237 70 67 196 32 134 65 74 154 48 4 130 72 99 131 116 23 186 16 34 93 116 231 48 27 241 9 92 27 116 101 192 66 192 69 73 86 5 173 175 80 8 62 128 80 92 4 10 133 22 92 212 64 73 49 127 55 214 18 200 180 246 192 189 139 203 225 59 103 115 133 8 133 240 200 128 183 0 3 120 221 128 47 227 124 122 20 192 132 163 121 120 14 112 1 71 64 117 156 79 139 72 247 82 176 90 88 88 208 158 164 82 90 10 86 67 240 238 13 48 97 47 13 122 98 119 151 76 179 73 26 116 19 246 238 5 8 161 56 5 197 108 185 44 122 62 143 158 207 147 45 151 101 10 138 33 20 249 151 118 160 123 2 195 94 167 163 60 207 83 158 231 169 94 167 163 78 96 184 3 221 191 54 8 97 197 133 165 140 239 139 225 251 56 142 131 227 56 24 190 79 198 247 197 133 165 16 86 34 1 38 236 103 193 72 4 1 162 105 88 150 133 101 89 136 166 145 8 2 178 96 152 176 63 22 16 194 250 52 164 231 10 5 140 82 9 17 193 182 109 108 219 70 68 48 74 37 230 10 5 166 33 29 194 250 8 32 4 49 160 177 120 155 174 233 58 34 242 167 129 8 154 174 147 8 2 22 193 48 160 17 130 192 237 10 225 213 44 180 94 44 47 27 147 103 103 16 139 161 148 162 223 239 3 144 76 38 17 17 184 185 225 106 109 141 15 231 231 131 75 168 55 224 157 132 16 123 12 87 79 193 154 63 62 230 97 181 138 82 10 165 20 181 90 13 128 118 187 141 136 32 34 252 56 61 229 98 99 131 46 124 255 12 147 154 192 102 28 204 153 92 142 120 165 114 103 20 17 92 215 197 117 221 145 91 188 82 97 38 151 35 14 166 192 166 108 195 215 151 144 154 61 56 96 162 94 191 75 255 61 192 8 64 68 184 110 181 184 220 218 226 61 124 147 67 24 62 3 121 192 255 233 39 240 17 148 254 9 14 7 240 102 34 226 47 162 116 13 195 30 52 127 1 151 222 125 8 28 180 225 19 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'pmm 1/1/2009 19:24'!
haloCss
	^ '.halo {
	margin: 2px;
	border: 1px solid #aaa;
}

/* header */
.halo-header {
	overflow: hidden;
	padding: 2px;
	color: #444;
	background-color: #eee;
	border-bottom: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
.halo-header a {
	text-decoration: none;
}
.halo-header div {
	float: left;
}
.halo-header div.classnamehaloplugin,
.halo-header div.browserhaloplugin,
.halo-header div.inspectorplugin,
.halo-header div.styleshaloplugin {
	float: left;
	display: block;
	padding-right: 5px;
}
.halo-header div.browserhaloplugin, div.window-titlebar div.browserhaloplugin {
	background: url(codebrowser.png) no-repeat;
}
.halo-header div.inspectorplugin, div.window-titlebar div.inspectorplugin {
	background: url(inspector.png) no-repeat;
}
.halo-header div.styleshaloplugin, div.window-titlebar div.styleshaloplugin {
	background: url(styleeditor.png) no-repeat;
}
.halo-header div.browserhaloplugin a,
.halo-header div.inspectorplugin a,
.halo-header div.styleshaloplugin a {
	width: 16px;
	display: block;
	text-indent: -32000px;
	background-position: 0 50%;
	outline: none;
}
.halo-header div.modehaloplugin {
	float: right;
	display: block;
}
.halo-header div.modehaloplugin a {
	color: #444;
}
.halo-header div.modehaloplugin a:hover {
	color: #111;
}
.halo-header div.modehaloplugin a.active {
	font-weight: bold;
}
div.window-titlebar div.profilertoolplugin {
	background: url(profiler.png) no-repeat;
}
div.window-titlebar div.memorytoolplugin {
	background: url(memory.png) no-repeat;
}
div.window-titlebar div.configuretoolplugin {
	background: url(config.png) no-repeat;
}
div.window-titlebar div.deprecationtoolplugin {
	background: url(deprecated.png) no-repeat;
}

/* body */
.halo-body {
	clear: both;
	padding: 2px;
}

/* source */
.halo-source .tag-known {
	font-weight: bold;
	color: navy;
}
.halo-source .attribute-known {
	color: navy;
}
.halo-source .attribute-value {
	color: purple;
}
.halo-source .comment {
	font-style: italic;
	color: green;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:58'!
inspectorPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 240 0 240 0 239 52 6 103 27 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 5 16 15 5 37 253 173 47 0 0 1 246 73 68 65 84 56 203 157 146 77 107 19 81 24 133 159 59 201 36 77 154 102 134 74 82 10 10 181 93 104 26 69 20 193 133 184 20 10 85 119 226 38 191 192 111 169 244 31 136 182 36 65 68 20 116 89 119 85 16 197 77 168 59 65 236 162 84 40 164 137 86 171 150 80 53 141 205 71 39 77 50 51 215 69 72 73 66 82 170 103 119 15 239 61 239 225 188 71 60 121 250 120 49 247 39 119 140 61 64 85 213 231 19 183 38 47 182 144 211 209 187 150 220 35 238 77 223 145 237 162 78 41 235 92 62 191 185 235 118 77 211 59 242 78 33 196 206 35 153 76 118 28 10 133 66 93 133 119 28 180 15 102 50 25 102 95 204 2 144 152 75 0 208 180 107 119 7 223 190 175 146 74 167 57 122 106 140 109 197 139 105 43 184 100 133 212 252 107 38 110 223 140 196 162 247 159 53 254 40 237 14 52 93 35 149 78 115 232 228 24 159 11 94 6 7 2 140 28 8 82 18 62 180 209 113 252 154 62 115 237 198 149 227 93 29 36 230 18 12 135 79 179 82 112 115 233 204 16 190 30 21 211 182 81 29 10 239 150 37 193 35 227 54 75 111 22 0 1 160 116 10 75 122 3 12 13 232 88 182 100 219 52 169 212 44 202 85 139 126 159 155 95 101 181 37 9 69 74 137 148 118 75 48 110 183 11 132 160 92 181 168 214 36 155 91 53 220 170 131 253 253 30 164 16 45 93 112 2 182 105 154 45 78 108 99 131 53 163 138 223 163 162 247 185 176 45 137 223 227 228 211 70 129 125 61 150 157 107 114 174 212 43 234 66 211 116 52 77 231 194 185 243 164 23 222 18 236 19 124 249 153 39 155 43 145 55 42 124 92 89 167 84 174 144 91 122 229 44 21 139 63 26 2 34 26 159 154 177 44 43 210 124 13 195 48 112 56 84 78 156 141 176 188 86 100 203 84 24 236 149 172 47 190 100 248 224 8 0 31 230 223 167 30 62 120 116 88 116 107 216 213 235 151 167 2 129 224 100 51 231 235 245 17 30 13 243 59 155 173 247 101 245 43 130 127 68 44 30 149 13 145 255 18 0 148 88 60 106 1 148 13 131 191 6 140 246 211 127 51 231 46 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 19:44'!
memoryPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 10 19 17 58 52 159 194 36 103 0 0 1 240 73 68 65 84 56 203 165 147 61 104 20 65 24 134 159 221 153 157 221 189 194 20 34 18 209 75 97 12 66 208 72 2 1 33 96 97 115 96 17 36 106 180 17 82 88 137 193 70 17 15 46 133 164 176 178 49 130 149 86 134 147 72 136 88 156 66 42 27 65 68 61 73 180 9 130 7 241 206 52 10 130 119 59 127 22 49 49 33 39 74 124 225 101 186 103 158 225 251 38 40 149 138 15 128 115 108 35 222 251 105 74 165 162 111 181 154 190 217 106 250 191 197 57 231 51 157 173 183 84 42 122 185 70 155 184 59 79 185 82 253 167 155 71 11 135 185 112 162 7 0 9 16 69 138 114 165 138 234 0 37 99 136 20 103 142 46 67 16 50 251 166 11 156 7 60 24 139 54 134 114 165 202 248 233 62 0 194 141 100 21 167 68 105 202 217 161 58 23 135 7 17 74 146 38 9 105 46 69 37 41 34 151 144 36 9 0 214 152 223 6 107 17 42 70 36 49 253 61 123 8 115 5 250 187 27 168 232 19 143 23 14 32 188 3 35 201 66 13 128 177 118 171 65 148 40 70 6 107 236 219 213 193 203 165 6 93 249 83 136 72 146 36 49 81 162 16 113 132 138 213 159 13 78 14 212 8 3 137 200 21 224 219 44 65 48 130 144 130 171 199 159 179 80 223 141 179 14 235 44 83 111 3 140 109 3 184 60 122 157 128 128 143 181 25 222 47 127 37 191 23 14 229 119 114 164 211 48 216 55 142 247 0 158 169 251 183 218 3 110 207 220 68 40 129 148 17 66 10 62 55 230 232 221 63 202 195 215 53 204 247 59 88 99 177 198 254 122 130 221 10 120 242 174 155 40 85 168 88 17 197 10 33 63 112 176 243 25 190 89 35 12 2 158 46 245 210 252 145 1 139 237 13 96 117 222 22 71 232 29 206 57 46 61 234 192 249 29 104 109 208 86 99 113 171 6 27 1 90 103 140 13 15 112 111 238 213 38 220 226 60 192 139 182 155 184 242 101 101 179 193 149 243 67 92 27 59 134 214 25 89 43 67 27 141 214 107 231 134 26 77 163 81 95 135 73 96 122 114 242 198 246 127 227 255 230 39 112 67 0 83 217 168 244 129 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:59'!
profilerPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 4 115 66 73 84 8 8 8 8 124 8 100 136 0 0 0 9 112 72 89 115 0 0 4 157 0 0 4 157 1 124 52 107 161 0 0 0 25 116 69 88 116 83 111 102 116 119 97 114 101 0 119 119 119 46 105 110 107 115 99 97 112 101 46 111 114 103 155 238 60 26 0 0 3 25 73 68 65 84 56 141 101 147 79 104 219 117 24 198 63 223 111 218 181 105 27 243 167 165 127 213 181 22 35 181 171 237 198 152 204 22 230 193 169 200 14 67 24 84 152 135 194 16 188 8 66 17 113 243 44 115 189 120 16 65 135 5 157 90 240 160 224 230 182 67 41 108 172 44 235 97 3 219 117 90 211 218 37 105 154 52 77 211 52 77 242 203 239 251 199 131 53 108 250 192 115 123 223 207 203 3 239 35 172 181 60 170 177 209 113 25 104 14 156 10 132 90 94 110 244 53 29 208 74 233 236 230 230 189 108 58 115 253 171 111 63 185 202 127 36 30 5 188 59 246 241 96 248 64 223 55 62 191 127 64 169 138 168 171 3 173 20 219 185 50 78 197 213 249 173 252 157 244 218 218 91 95 127 255 233 234 255 0 227 239 157 127 59 220 223 247 89 93 67 77 176 183 219 71 103 48 129 150 65 124 161 126 42 21 205 159 75 113 230 34 247 217 217 113 210 235 177 216 169 139 151 206 223 168 2 206 156 254 176 249 224 139 135 127 243 135 188 29 195 71 2 120 202 119 168 245 182 83 44 149 8 118 190 134 244 120 81 74 145 201 100 185 118 121 150 100 114 251 143 116 34 49 48 57 53 81 145 0 79 247 118 127 39 106 100 199 161 161 30 230 102 127 165 232 212 163 157 36 30 247 47 246 213 122 144 82 34 165 36 24 244 51 114 236 32 96 194 77 1 255 231 0 114 108 116 92 120 27 26 15 181 181 122 233 122 178 131 55 222 252 128 153 217 24 209 165 251 56 187 15 1 133 16 226 159 188 66 208 209 217 194 11 131 61 212 213 213 31 5 144 66 136 103 129 64 40 244 4 198 24 16 130 177 119 206 177 190 219 207 236 92 148 197 197 69 172 181 143 185 185 37 136 54 170 125 108 116 188 94 122 106 106 142 26 107 106 125 190 122 86 86 163 104 173 81 74 113 226 228 25 86 182 70 184 114 245 38 174 235 98 173 197 24 67 98 45 134 223 223 132 209 38 4 246 57 169 149 138 56 101 199 221 201 151 120 170 107 127 21 176 177 177 129 197 195 240 240 8 214 90 180 214 24 99 104 111 235 36 159 47 0 228 64 44 73 107 237 239 21 167 146 201 110 230 80 74 85 125 225 194 4 199 143 191 194 208 208 32 90 235 170 141 49 100 82 89 132 144 201 201 169 137 162 156 156 154 176 197 194 238 194 194 252 67 50 153 44 74 41 92 215 229 236 217 143 8 135 195 184 174 91 133 106 173 201 109 21 184 125 123 30 167 84 140 0 72 128 92 38 115 122 183 224 108 220 186 113 143 157 157 66 117 120 59 159 163 92 46 85 33 197 221 50 215 126 185 9 200 196 149 235 63 156 171 2 38 167 38 74 15 22 238 126 17 141 166 203 63 253 56 67 34 190 177 119 85 163 181 65 107 67 124 53 205 165 201 203 36 83 185 98 36 50 125 49 182 22 13 10 33 164 176 214 34 132 104 4 122 7 250 142 188 62 252 210 171 239 123 27 26 219 189 245 251 232 238 105 163 226 104 150 151 227 184 174 182 249 252 86 106 122 230 231 47 227 201 149 8 240 0 88 174 118 65 8 225 7 158 169 173 217 183 255 240 208 177 147 173 173 157 207 55 183 180 117 25 173 77 42 21 95 79 165 18 75 119 231 111 77 91 107 215 128 5 32 102 173 181 143 181 113 239 227 26 129 16 224 7 124 123 49 139 64 1 200 0 219 214 90 243 239 206 223 67 200 195 25 126 17 209 190 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing' stamp: 'lr 1/7/2009 13:53'!
selectorsToInclude
	^ #( toolbarCss haloCss toolsCss windowCss )! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:59'!
styleeditorPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 214 4 9 20 4 42 36 195 187 166 0 0 2 112 73 68 65 84 56 203 173 147 221 75 83 113 24 199 63 155 155 110 57 245 164 169 232 24 180 240 173 50 207 48 74 144 68 27 82 209 141 43 147 145 136 226 159 97 36 236 70 130 174 162 232 38 34 42 86 104 26 42 5 74 47 243 5 65 212 110 52 148 48 95 74 156 107 206 236 156 249 50 117 110 167 139 58 232 130 186 144 30 248 193 247 226 249 124 248 61 207 143 31 28 172 146 107 156 213 74 119 119 183 114 16 216 180 15 222 19 184 65 116 67 167 27 228 223 167 211 13 226 31 112 226 126 184 198 89 173 104 84 24 232 183 55 54 10 73 201 41 16 217 37 184 178 66 95 107 171 4 84 44 222 110 89 150 229 96 219 204 204 76 89 93 109 61 85 85 85 212 56 171 105 111 123 169 87 5 157 246 250 122 135 226 245 18 24 25 1 69 225 136 77 132 212 52 94 127 15 140 249 46 86 230 100 103 153 15 23 228 159 160 188 188 92 133 117 64 36 14 224 42 60 40 42 41 73 88 236 233 97 119 99 131 104 56 204 178 94 199 156 205 198 194 217 211 230 230 155 46 163 86 27 135 40 138 108 132 130 60 122 248 88 7 68 0 180 234 112 74 40 4 202 222 78 190 230 230 225 63 83 76 83 83 51 62 159 143 188 188 60 218 59 94 176 24 76 222 108 56 89 89 168 246 169 2 79 48 16 32 45 63 31 157 193 192 252 229 75 248 47 216 185 238 172 197 231 243 97 52 26 233 31 232 227 211 236 23 4 177 250 208 146 144 237 138 17 76 31 79 126 254 166 191 87 193 100 226 104 105 41 19 69 133 92 113 92 99 109 109 13 69 81 88 95 15 50 60 58 202 80 192 138 201 168 195 159 146 105 143 17 124 168 73 170 141 27 44 211 188 21 38 232 26 241 144 62 61 133 167 239 61 130 32 32 203 50 119 238 221 229 227 143 12 66 187 113 108 135 35 49 239 170 3 208 155 37 123 162 152 195 192 173 49 182 36 3 130 55 132 102 106 146 150 251 207 8 71 34 172 104 173 44 109 9 164 101 89 9 200 219 100 202 126 79 140 0 32 204 38 74 244 87 150 204 195 196 235 102 241 246 26 176 228 22 99 200 182 112 42 43 129 213 245 29 62 15 116 72 54 105 201 21 35 8 123 5 207 106 116 206 97 201 201 96 97 122 25 128 236 226 45 178 114 94 49 120 99 202 247 77 41 72 4 200 148 253 30 155 180 228 122 50 249 110 92 21 104 0 28 117 86 49 122 46 208 127 190 193 34 24 73 37 202 46 235 138 159 161 167 43 146 118 40 189 162 203 61 63 254 183 143 161 81 131 163 206 42 238 28 219 113 233 205 146 93 189 85 252 92 188 235 95 240 127 169 159 24 23 11 103 188 240 115 88 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 9/25/2008 17:53'!
toolbarCss
	^ 'body {
	margin-bottom: 25px;
}
#toolbar {
	z-index: 20;
	position: fixed;
	left: 0;
	right: 0;
	bottom: 0;
	padding: 2px;
	color: #444;
	background-color: #eee;
	border-top: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
#toolbar a {
	color: #444;
	padding-left: 3px;
	padding-right: 3px;
	text-decoration: none;
}
#toolbar a:hover {
	color: #111;
}
#toolbar a.deprecationtoolplugin {
	color: #ff7000;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 1/7/2009 13:53'!
toolsCss
	^ '.tool strong {
	color: #444444;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 12px;
	margin: 2px
}

.tool a, .tool a:link, .tool a:active, .tool a:visited, .tool a:focus, .tool a:hover {
	color:#008AFF;
	font-family: Helvetica, Verdana, Arial, sans-serif;
	font-size: 12px;
}

.tool table {
	border-collapse:collapse;
}

.tool table td {
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
	padding-left: 5px;
	padding-right: 5px;
}
	
.tool .right {
	text-align: right;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 1/7/2009 13:53'!
windowCss
	^ '.window {
	margin: 1em;
	border: 1px solid #aaa;
}
.window .window-titlebar {
	color: #444;
	padding: 5px;
	overflow: hidden;
	background-color: #eee;
	border-bottom: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
.window .window-titlebar .window-title {
	float: left;
	font-weight: bold;
	padding-left: 20px;
}
.window .window-titlebar .window-close {
	float: right;
}
.window .window-titlebar .window-close a {
	color: #444;
	text-decoration: none;
}
.window .window-titlebar .window-close a:hover {
	color: #111;
}
.window .window-content {
	clear: both;
	padding: 2px;
	background-color: #fff;
}'! !

!WAFileLibrary methodsFor: '*seaside-development' stamp: 'pmm 4/22/2006 00:41'!
configurationComponent
	^ WAFileLibraryEditor new
		library: self;
		yourself! !

WAFileLibrary subclass: #WAHandlerEditorFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAHandlerEditorFiles methodsFor: 'accessing-files' stamp: 'lr 5/22/2007 21:52'!
faviconIco
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(0 0 1 0 1 0 16 16 0 0 1 0 32 0 104 4 0 0 22 0 0 0 40 0 0 0 16 0 0 0 32 0 0 0 1 0 32 0 0 0 0 0 0 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 252 252 252 253 247 247 247 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 103 117 237 253 42 51 220 253 229 230 239 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 72 116 250 253 0 51 246 253 73 95 225 253 247 247 247 253 255 255 255 253 255 255 255 253 255 255 255 253 253 253 253 253 249 249 249 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 83 137 252 253 0 87 254 253 0 88 252 253 126 146 226 253 251 251 251 253 242 242 247 253 164 164 233 253 70 70 222 253 30 30 216 253 226 226 237 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 95 152 252 253 0 126 255 253 0 111 255 253 3 103 251 253 63 97 231 253 17 55 231 253 0 45 236 253 0 11 226 253 32 33 220 253 242 242 245 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 252 252 252 253 79 145 249 253 0 158 255 253 0 98 255 253 0 149 255 253 0 149 254 253 0 106 250 253 0 33 233 253 2 31 232 253 185 185 233 253 254 254 254 253 255 255 255 253 255 255 255 253 254 254 254 253 232 237 245 253 148 184 243 253 58 136 245 253 0 136 254 253 0 163 255 253 0 113 255 253 0 134 255 253 0 118 255 253 0 84 250 253 0 92 250 253 107 113 225 253 253 253 253 253 255 255 255 253 255 255 255 253 254 254 254 253 107 164 246 253 7 108 252 253 0 118 255 253 0 135 255 253 0 134 255 253 0 128 255 253 0 104 255 253 0 82 255 253 0 110 255 253 0 146 255 253 4 77 240 253 231 231 237 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 80 153 251 253 1 113 254 253 0 129 255 253 0 143 255 253 0 147 255 253 0 144 255 253 0 116 255 253 0 89 255 253 0 96 255 253 0 144 255 253 0 114 250 253 143 149 220 253 253 253 253 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 227 238 251 253 158 199 250 253 88 171 251 253 9 149 254 253 0 167 255 253 0 121 255 253 0 143 255 253 0 136 255 253 0 89 255 253 0 104 253 253 7 60 235 253 187 187 226 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 138 184 251 253 0 155 255 253 0 109 255 253 0 162 255 253 0 143 255 253 0 133 255 253 0 88 251 253 0 30 233 253 25 31 219 253 223 223 236 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 161 197 252 253 0 137 255 253 0 115 255 253 4 140 253 253 154 182 242 253 163 188 251 253 89 130 247 253 19 37 230 253 0 0 222 253 151 151 227 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 169 201 252 253 0 109 255 253 0 117 255 253 113 161 240 253 253 253 253 253 255 255 255 253 254 254 254 253 250 250 252 253 212 212 245 253 249 249 251 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 177 205 252 253 0 94 255 253 38 115 246 253 241 243 247 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 227 236 253 253 61 127 250 253 197 213 243 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0) asByteArray ].
	^ cache at: 1! !

!WAHandlerEditorFiles methodsFor: 'accessing-files' stamp: 'lr 12/29/2008 11:59'!
handlerCss
	^ '/* html */
body {
	color: #002842;
	font-size: 12px;
	font-family: Helvetica, Verdana, Arial, sans-serif;
}
input, textarea, select {
	color: #002842;
	margin-right: 0.5em;
	font-family: Helvetica, Verdana, Arial, sans-serif;
}
input.text, textarea {
	width: 200px;
}
a {
	color: #008aff;
	text-decoration: none;
}

/* headings */
h1, h2, h3, h4, h5, h6 {
	color: #01598d;
	margin-bottom: 1ex;
	font-weight: normal;
}
table {
	border: 0;
	border-collapse: collapse;
}
td, th { padding: 3px 1em 3px 0; }
th { text-align: right; }

/* special */
h1.logo a { 
	width: 200px;
	height: 106px;
	outline: none;
	display: block;
	text-indent: -100em;
	background: url(logo.png) no-repeat;
}
h1.title a { color: #01598d; }
span.unspecified { color: #ff7000; }
a.download {
	background: url(save.png) no-repeat;
	background-position: 0 50%;
	padding-left: 18px;
}

/* walkback */
.walkback th {
	width: 150px;
	text-align: left;
	vertical-align: top;
}'! !

!WAHandlerEditorFiles methodsFor: 'accessing-files' stamp: 'lr 12/29/2008 11:51'!
handlerJs
	^ 'function submitForm(element) {
	var hidden = document.createElement("input");
	hidden.name = /[?&](\d+)/.exec(element.href)[1];
	hidden.type = "hidden"; hidden.value = "";
	while (element && element.tagName !!= "FORM")
		element = element.parentNode;
	element.appendChild(hidden);
	element.submit();
	return false;
}'! !

!WAHandlerEditorFiles methodsFor: 'accessing-files' stamp: 'lr 12/29/2008 12:05'!
logoPng
	"The official logo was designed by Samuel Morello. He released it under the Creative Commons Attribution-No Derivative Works 3.0 license (http://creativecommons.org/licenses/by-nd/3.0/)."
	
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 200 0 0 0 107 8 3 0 0 0 5 14 61 236 0 0 0 25 116 69 88 116 83 111 102 116 119 97 114 101 0 65 100 111 98 101 32 73 109 97 103 101 82 101 97 100 121 113 201 101 60 0 0 3 0 80 76 84 69 132 164 183 238 198 176 162 187 202 255 135 0 155 183 200 167 197 216 8 94 145 5 149 237 255 165 0 207 175 160 223 3 1 238 238 238 222 222 222 8 150 238 229 21 3 183 212 230 78 164 217 139 186 214 71 132 168 1 88 141 196 217 229 232 232 232 102 182 232 17 99 149 211 211 211 0 142 229 235 235 235 234 234 234 193 205 213 1 83 133 254 72 0 73 170 229 1 86 137 0 137 220 217 225 230 42 150 217 199 144 144 203 204 205 12 96 147 2 143 229 255 156 0 211 218 223 189 203 211 208 208 208 0 146 236 178 192 200 246 151 78 35 110 154 209 221 229 53 121 161 163 205 231 219 219 219 214 214 214 118 188 231 203 213 219 145 196 226 121 161 186 220 220 220 37 158 232 12 152 238 212 212 212 43 162 235 88 178 233 255 107 0 16 154 238 237 189 169 216 216 216 12 146 229 206 74 74 132 189 225 210 56 54 125 181 215 255 147 0 255 99 0 255 91 0 0 144 232 238 211 197 241 110 42 255 116 0 0 140 226 255 82 0 176 197 209 49 165 236 247 57 0 138 197 232 140 192 224 194 208 216 133 195 233 143 192 221 255 125 0 55 117 154 107 154 181 115 159 185 80 137 171 182 180 180 243 180 143 153 189 212 99 174 220 151 201 232 217 222 225 42 114 158 202 209 212 97 149 179 131 169 191 28 158 236 185 163 163 174 208 229 110 176 217 9 140 220 87 171 223 199 191 191 214 152 118 0 145 234 2 148 237 245 157 94 200 112 108 29 146 218 9 91 141 18 148 227 210 214 216 235 31 0 225 228 230 168 191 205 217 78 48 26 105 152 157 203 232 3 90 142 143 170 186 19 155 238 126 192 232 0 135 217 50 160 228 198 200 201 182 199 210 228 156 145 109 147 171 67 124 158 216 221 223 241 43 1 58 162 228 23 97 141 15 142 218 64 170 235 59 167 235 242 167 114 157 201 228 95 146 177 236 225 221 20 153 233 0 146 235 134 192 228 184 134 132 26 102 148 106 151 178 0 138 223 111 157 184 240 50 0 223 226 228 225 226 226 5 145 231 8 148 234 98 141 167 152 176 190 213 35 29 22 156 238 185 206 219 163 182 194 120 155 176 5 142 226 217 219 220 16 93 139 147 199 230 29 107 153 17 152 236 198 210 217 191 211 223 226 137 93 8 143 226 159 198 222 48 111 150 3 147 234 35 103 144 228 229 230 3 145 232 211 213 214 5 88 138 79 175 234 54 167 236 14 150 233 5 92 144 229 229 229 251 251 251 228 228 228 230 230 230 252 252 252 247 247 247 250 250 250 249 249 249 224 224 224 227 227 227 248 248 248 243 243 243 246 246 246 244 244 244 245 245 245 241 241 241 240 240 240 242 242 242 226 226 226 225 225 225 231 231 231 21 102 151 226 227 227 228 229 229 221 221 221 144 199 232 189 197 202 103 151 180 14 144 224 5 144 229 208 216 221 64 127 166 183 100 100 220 223 224 251 87 27 246 236 230 224 85 85 23 153 232 26 153 229 245 130 46 88 142 175 95 144 172 214 217 219 172 203 222 13 139 216 66 161 219 12 89 136 221 224 226 77 129 160 253 121 14 216 205 200 143 199 234 250 100 11 145 177 197 252 112 13 248 78 0 250 89 0 148 174 190 237 85 55 242 104 29 200 93 84 251 119 36 228 124 70 253 253 253 254 254 254 255 255 255 148 77 63 186 0 0 23 172 73 68 65 84 120 218 212 155 11 84 84 231 181 199 81 8 24 230 136 6 56 48 14 136 84 171 69 192 2 206 1 65 209 73 198 68 25 72 17 212 168 248 106 19 49 40 106 47 182 209 24 174 33 190 72 53 105 53 177 154 164 162 141 77 172 137 137 49 239 230 250 224 204 153 215 57 243 126 153 78 181 213 235 189 183 183 105 82 155 222 155 107 109 111 31 51 116 239 239 59 243 64 161 139 68 71 195 151 181 178 100 6 87 190 223 236 189 255 251 191 247 153 36 244 12 170 19 194 211 231 59 9 131 139 195 104 182 88 204 198 208 96 7 9 233 255 243 155 223 100 61 38 125 104 144 131 4 77 127 171 173 253 70 149 194 222 7 201 160 2 209 223 95 11 231 45 70 97 186 62 187 6 19 72 200 60 68 87 91 171 107 184 83 114 89 130 131 26 196 58 68 167 171 213 233 254 82 196 58 174 75 174 65 5 98 26 162 211 232 116 77 181 111 169 195 201 21 10 5 141 70 99 16 36 57 97 80 213 250 16 93 189 166 54 177 169 225 78 47 36 23 66 152 45 78 155 205 105 213 7 67 131 11 228 30 93 98 125 109 83 65 61 36 151 205 98 54 91 29 63 124 242 191 102 205 122 82 97 55 15 46 16 251 51 186 154 196 218 250 130 26 221 91 156 95 161 184 255 201 255 79 75 197 195 65 166 13 42 16 231 51 154 154 26 157 174 96 88 77 195 223 159 124 235 63 242 242 230 61 69 72 118 64 241 15 38 16 163 227 25 77 65 65 125 109 205 176 97 137 160 94 154 250 250 63 61 133 28 179 118 248 109 131 8 36 20 50 187 190 83 95 48 44 177 182 105 216 176 97 5 53 53 53 137 154 131 105 105 16 146 213 143 178 206 193 146 90 40 80 86 207 253 127 4 134 154 90 13 5 73 172 157 247 212 188 121 105 169 207 143 135 86 31 76 24 20 20 122 139 201 243 195 123 190 254 71 8 200 176 2 13 20 73 65 65 77 125 67 94 158 78 115 48 245 223 191 173 101 109 131 65 181 192 186 219 21 247 63 243 155 250 250 68 40 14 56 245 181 137 5 5 137 186 188 60 77 98 226 159 82 103 45 231 4 116 44 9 95 126 14 235 61 95 255 159 250 166 196 130 97 242 73 108 208 36 66 56 0 167 166 126 211 203 203 139 124 164 205 223 94 16 139 77 161 176 5 67 253 207 125 160 185 150 239 104 52 192 81 83 32 147 20 36 54 52 212 54 52 104 224 133 196 121 105 171 199 51 42 226 234 111 39 136 149 229 241 8 30 48 27 193 254 96 140 14 205 53 7 40 26 26 154 128 163 64 179 233 249 115 199 88 135 57 116 123 77 163 211 96 160 32 130 41 40 131 68 99 19 193 50 218 254 6 151 175 39 71 3 150 177 150 112 96 153 20 212 92 125 121 185 50 108 233 111 31 136 217 111 48 140 221 122 234 84 171 32 248 123 113 244 62 70 251 144 223 232 160 249 97 110 225 229 107 160 62 26 26 242 116 137 240 167 171 105 203 57 214 65 125 240 237 3 81 25 12 35 166 79 155 54 124 106 169 228 181 196 130 4 205 38 147 213 24 1 49 185 197 59 223 250 139 78 87 47 151 73 65 83 131 174 73 151 87 219 148 152 168 73 251 107 145 95 30 77 110 33 72 168 119 111 48 24 30 155 113 247 180 225 41 41 175 123 125 30 99 56 185 140 142 28 154 113 172 137 82 25 45 78 5 175 30 127 231 223 255 175 86 211 68 64 52 13 77 160 87 160 190 245 154 121 169 95 101 220 183 46 181 204 168 77 122 114 173 96 196 111 88 32 32 91 16 100 253 115 162 232 70 16 56 118 160 192 67 74 39 199 26 194 215 244 22 187 75 101 96 184 29 255 242 141 90 13 144 212 52 212 98 150 53 229 61 117 85 247 167 180 180 111 203 33 137 63 136 69 214 166 28 75 48 182 166 161 212 31 71 144 245 197 17 16 19 75 40 198 102 182 182 142 40 5 13 200 193 225 47 136 211 147 221 166 200 225 3 69 111 53 64 75 108 106 168 39 229 210 52 47 237 169 171 243 82 239 213 170 236 198 91 33 191 246 176 52 9 108 47 16 155 193 240 217 150 187 33 32 109 207 49 140 2 174 108 85 17 138 201 89 187 167 31 217 114 100 238 252 67 130 228 50 155 205 122 68 65 22 143 130 255 223 134 196 97 5 186 6 168 115 168 250 196 250 131 169 105 7 211 82 191 42 146 228 138 55 136 5 32 198 206 63 117 234 33 65 242 218 141 49 53 237 64 16 200 172 226 182 251 8 136 21 179 170 180 124 238 145 45 119 223 61 13 75 167 92 242 249 60 22 11 33 193 164 212 91 221 190 134 68 104 135 58 84 46 157 166 169 30 140 86 234 166 84 57 185 226 13 194 242 134 204 211 195 225 131 255 133 79 204 209 95 3 130 153 181 191 14 64 220 122 61 164 213 99 15 65 44 40 7 252 133 148 86 145 241 217 173 132 132 214 189 201 15 32 154 188 122 226 123 55 109 58 120 245 234 65 28 71 238 213 130 249 141 55 8 4 100 236 105 172 232 226 169 162 40 68 65 130 65 10 2 153 53 234 62 70 116 233 21 188 225 177 242 8 6 254 133 182 49 111 50 1 143 19 72 140 132 164 39 100 249 97 94 83 77 67 67 34 112 252 235 243 223 125 57 53 53 45 109 19 146 220 249 51 144 146 56 131 184 120 126 43 126 190 197 109 191 102 24 201 44 23 137 209 234 176 17 16 124 131 128 56 121 254 103 229 91 128 99 90 152 99 127 221 212 69 106 181 202 1 36 122 57 37 45 67 242 234 235 243 116 77 181 243 254 186 124 199 248 29 171 239 77 165 231 121 209 21 119 27 159 195 243 167 48 32 251 235 198 48 12 171 39 26 107 194 106 240 67 95 255 12 53 171 142 128 64 6 126 70 57 182 236 206 218 157 178 126 253 254 182 81 51 31 212 106 37 151 211 14 32 180 61 90 135 228 105 106 243 116 16 143 229 227 213 62 175 168 29 255 252 44 4 89 237 117 199 27 36 200 243 135 118 147 128 212 189 19 128 146 14 99 208 131 32 109 163 0 196 231 134 12 220 77 210 106 213 227 143 9 165 167 33 177 70 141 154 115 153 227 24 55 36 151 57 12 114 79 94 109 94 222 213 131 79 173 30 31 96 21 46 5 116 151 234 111 127 247 175 171 171 253 158 120 131 132 32 34 89 36 225 179 2 12 99 130 182 224 244 163 198 142 248 108 225 228 82 195 103 40 190 8 226 5 144 201 119 147 242 88 8 58 45 108 5 240 81 115 14 140 227 184 42 133 203 105 178 144 93 34 20 251 61 121 121 243 160 204 159 223 81 133 107 45 236 46 172 192 168 25 131 2 58 73 92 65 160 237 241 124 230 238 105 41 171 182 2 135 2 82 196 129 24 243 79 31 129 178 158 254 248 47 134 147 79 254 62 70 130 158 153 69 56 86 101 34 200 227 132 227 192 35 74 78 171 112 217 98 64 16 99 19 204 182 16 2 148 100 189 197 233 81 40 20 46 187 57 174 170 69 210 1 174 56 182 117 114 166 200 48 60 220 199 10 28 153 187 143 108 33 234 116 100 55 214 14 128 136 146 0 153 69 228 106 238 88 65 144 164 103 49 177 14 124 229 17 165 82 171 112 219 76 86 90 237 65 235 61 128 145 54 107 121 181 32 251 171 16 62 193 178 130 26 4 227 216 71 100 157 53 249 73 91 247 137 162 228 36 205 34 115 238 145 176 56 165 144 128 80 144 210 85 248 82 202 158 177 146 228 245 62 139 1 249 10 130 112 42 5 174 118 137 0 7 205 247 167 165 165 190 188 90 158 109 35 255 153 96 40 94 94 43 214 146 27 33 36 135 38 151 151 103 250 188 172 222 4 205 98 6 193 64 137 69 109 170 11 131 100 82 180 211 99 189 151 50 91 103 144 128 124 101 156 82 169 6 16 123 4 196 245 228 172 123 151 23 137 42 231 173 120 98 69 250 132 133 206 19 32 82 54 254 231 165 167 166 173 47 222 179 66 18 204 57 188 97 50 114 192 141 167 207 192 87 219 34 32 35 104 136 230 78 46 31 51 245 131 58 2 242 131 7 149 74 70 225 118 160 254 146 254 163 183 43 24 109 149 164 114 152 131 61 113 7 1 145 244 228 16 159 72 221 46 136 212 41 146 68 35 96 162 133 174 135 53 13 63 238 201 148 132 242 226 253 81 144 135 40 200 225 51 117 117 248 26 130 92 110 84 86 75 170 24 16 163 217 233 86 41 220 206 190 56 110 50 72 40 104 243 71 6 10 94 101 13 66 117 103 174 34 22 229 117 65 176 241 80 10 132 227 141 86 159 207 59 118 95 91 12 136 236 75 8 5 130 188 125 57 87 89 173 133 123 59 76 22 61 181 91 104 28 77 38 82 218 113 6 177 168 104 167 27 59 98 68 233 99 24 20 43 154 245 105 49 32 147 177 62 214 23 111 23 25 81 244 158 218 127 45 200 126 153 99 227 211 107 222 121 148 227 180 94 21 202 175 89 31 246 141 100 210 138 207 23 6 98 151 31 116 48 202 220 122 106 250 170 85 83 247 60 244 115 32 113 243 134 173 17 16 48 94 11 167 17 231 190 142 97 12 162 55 171 152 132 36 12 34 139 216 204 237 89 239 188 121 65 173 213 2 8 175 80 120 162 17 9 253 179 139 36 220 28 8 50 42 241 32 74 173 97 85 74 73 201 58 196 243 110 217 52 18 16 5 180 61 106 188 178 170 2 172 40 45 44 38 36 177 32 51 215 45 122 19 122 39 195 28 171 56 193 105 181 90 152 145 227 14 130 197 231 112 41 88 86 225 177 144 217 21 90 114 105 214 42 89 149 214 195 89 40 240 44 1 65 51 251 186 36 168 120 126 198 112 106 120 213 1 149 87 88 184 190 184 184 23 200 254 186 167 63 86 7 32 235 196 103 199 108 159 250 224 79 181 218 28 4 49 199 19 4 212 41 39 186 39 96 173 33 163 65 16 50 247 144 249 142 218 240 182 253 83 199 10 124 24 164 109 138 87 0 42 152 177 208 240 46 170 98 84 18 128 172 199 144 32 136 240 16 246 149 226 182 237 19 3 140 87 244 110 125 15 146 108 227 26 45 228 86 124 65 66 33 179 92 215 20 68 96 245 10 224 56 125 228 141 55 104 69 64 25 215 213 181 101 18 16 242 89 183 77 241 161 163 154 75 43 250 1 0 17 132 249 196 174 3 136 55 6 132 17 125 210 136 125 196 53 94 214 106 25 133 199 9 32 198 120 128 132 87 7 6 195 138 5 87 150 44 107 110 94 214 178 66 144 114 124 62 95 214 145 125 0 178 42 235 245 173 251 136 250 212 61 43 8 8 66 100 117 138 24 11 18 16 21 8 66 222 233 5 178 11 56 132 215 139 177 236 95 29 201 105 197 56 128 196 148 53 145 167 159 119 118 93 108 222 156 61 97 66 242 230 74 9 188 148 248 201 175 129 227 204 145 201 146 36 150 83 21 133 174 215 15 8 3 32 252 252 225 50 136 15 64 82 16 164 120 238 46 224 192 86 9 1 217 184 134 227 36 119 12 72 207 13 131 92 35 79 100 166 104 252 232 236 217 179 217 200 209 221 145 209 2 238 118 69 214 190 125 111 76 27 126 74 242 138 204 39 111 207 153 51 103 212 152 75 189 64 188 172 64 64 224 211 126 128 241 197 128 48 80 36 175 35 200 250 226 233 165 18 128 204 32 115 213 184 69 28 103 80 220 68 16 98 158 236 78 167 53 98 104 13 134 137 93 155 17 3 57 146 59 50 50 202 30 13 4 42 166 238 59 115 230 204 225 44 201 199 48 21 27 1 100 251 155 36 8 125 128 212 61 32 74 160 197 20 100 20 1 153 76 65 142 140 144 36 169 116 21 177 241 35 115 171 185 156 155 7 18 179 142 229 109 100 230 134 188 90 112 81 198 0 14 8 72 198 201 78 181 250 167 27 55 2 199 225 61 146 200 4 170 22 61 61 114 81 5 35 242 138 62 65 160 242 133 24 144 0 227 147 50 215 163 98 23 23 111 245 122 47 205 32 166 113 237 29 48 142 16 23 47 175 182 110 8 36 162 178 148 196 111 7 63 11 241 72 39 73 53 33 187 36 155 112 228 231 31 213 106 63 217 184 113 230 225 195 239 29 46 159 200 4 2 85 199 212 208 16 4 87 95 32 168 197 18 130 44 164 5 115 159 154 17 189 153 195 9 71 219 190 242 173 219 1 99 206 129 109 235 138 148 74 62 214 51 126 113 144 112 89 27 12 187 10 135 38 37 117 2 137 193 132 67 222 71 52 24 31 13 93 144 116 188 131 128 36 112 218 79 126 57 19 65 218 218 166 63 48 145 1 22 134 145 60 214 88 16 31 5 193 154 254 5 105 243 229 41 116 102 87 3 73 233 244 226 98 34 218 163 8 6 12 35 133 69 74 134 165 158 241 139 131 132 203 218 131 20 159 182 63 92 86 114 118 194 132 205 203 78 240 60 155 195 243 141 52 167 206 99 151 88 66 56 70 39 112 92 46 128 188 248 34 128 180 213 109 127 238 18 184 12 81 97 141 130 140 154 194 80 16 18 18 0 129 234 153 145 130 205 113 206 125 90 117 21 35 206 0 12 116 94 115 8 198 182 113 157 69 69 28 171 26 176 250 94 11 210 91 158 220 128 113 161 165 153 170 19 92 189 236 2 230 215 135 203 200 15 199 119 1 136 208 18 1 89 57 238 237 183 127 69 64 224 115 157 58 229 18 52 4 133 41 22 68 140 130 148 99 131 121 108 42 186 149 57 7 102 115 90 136 223 179 239 17 43 60 231 0 98 108 187 12 28 74 137 165 99 213 231 6 161 195 93 100 175 73 154 119 123 89 88 101 147 187 187 187 187 48 8 21 205 201 112 186 63 250 16 110 35 156 71 144 209 163 19 170 57 110 54 128 124 240 65 219 254 54 114 246 180 130 142 42 194 32 224 74 24 209 79 65 128 100 6 238 74 90 201 86 235 0 128 112 18 20 20 41 113 18 141 109 227 102 143 7 14 145 85 185 7 28 144 24 16 172 8 79 14 153 237 236 196 250 35 199 149 227 17 149 237 238 238 232 200 190 0 23 104 207 38 80 75 241 83 45 220 44 131 40 171 171 87 94 126 245 87 31 212 81 16 248 215 153 249 240 11 50 200 126 2 2 110 236 52 225 40 62 13 144 135 246 20 211 101 201 108 37 231 21 212 129 11 15 206 164 43 135 145 119 21 22 21 21 85 123 33 177 92 196 250 126 62 144 176 123 226 233 115 47 16 60 248 243 149 205 145 180 234 198 170 206 72 130 27 36 117 227 153 208 8 28 21 101 221 97 16 101 53 119 226 193 153 95 251 160 110 191 28 146 54 116 238 114 31 105 35 62 209 15 173 142 54 240 148 231 86 188 57 166 141 114 108 155 173 172 246 230 48 85 85 85 39 22 205 158 189 168 19 130 1 135 19 144 195 102 183 70 2 50 48 144 136 202 78 92 80 113 8 81 28 65 167 193 144 91 66 57 210 151 118 101 19 142 140 37 144 249 157 19 58 186 187 55 95 1 142 198 178 228 40 8 87 205 169 223 25 115 24 64 138 101 146 85 165 212 52 98 41 140 90 164 14 176 146 144 69 2 210 86 247 226 212 153 114 65 108 251 221 183 148 213 130 138 101 170 212 106 152 165 170 149 74 200 42 206 203 230 168 220 192 129 206 119 64 1 145 65 168 9 228 27 43 211 203 74 154 203 150 84 192 127 31 133 183 139 112 100 183 124 42 8 149 200 145 159 191 12 204 233 143 219 247 126 84 153 11 191 114 229 44 105 135 249 20 164 138 227 212 85 199 90 199 188 23 37 153 79 76 35 213 166 69 106 53 206 82 235 233 12 130 20 175 110 167 5 81 164 172 134 79 95 193 50 132 4 80 180 2 96 40 220 30 224 136 38 214 128 64 66 46 244 178 67 47 110 150 171 225 56 180 12 224 152 88 130 28 201 203 176 50 23 116 35 71 254 226 42 244 19 120 63 126 215 146 100 154 112 50 136 40 130 140 6 124 98 235 152 51 197 68 185 234 234 178 240 87 183 210 141 244 34 45 128 248 70 96 179 160 26 123 224 242 29 107 183 109 131 128 20 41 181 120 111 23 12 105 188 96 240 179 72 1 63 194 32 34 115 12 24 132 112 52 166 71 60 96 71 71 51 234 172 33 137 190 112 5 65 62 77 70 142 252 119 213 140 32 17 142 220 139 68 187 206 118 135 65 48 181 0 196 231 245 182 238 110 171 195 233 123 212 24 52 232 91 137 149 61 112 23 167 245 51 226 138 185 180 50 176 168 59 149 179 199 141 27 217 94 132 153 5 23 247 120 108 46 133 124 224 39 8 135 21 56 244 3 228 64 144 144 9 229 137 150 3 181 78 25 29 45 8 210 69 56 160 170 5 73 218 69 64 70 3 8 111 130 145 149 31 90 130 24 221 231 151 70 34 2 2 188 96 209 39 151 0 196 251 233 41 186 156 90 135 83 82 57 9 1 128 112 188 200 136 83 234 100 142 113 141 80 210 185 160 79 202 106 17 34 0 1 112 56 108 54 143 203 237 6 10 135 195 110 50 65 157 71 57 6 4 2 89 148 132 221 130 90 114 114 210 63 132 203 46 35 100 19 58 37 201 235 19 55 32 7 130 176 32 169 124 203 4 194 177 84 104 201 136 128 228 174 219 56 115 102 150 207 43 121 165 201 31 144 244 153 173 14 136 98 57 21 39 4 201 1 223 146 245 43 108 22 143 172 201 37 226 164 132 72 250 128 195 99 115 218 237 224 176 157 128 227 128 63 202 24 3 231 0 16 92 70 85 52 19 142 230 243 45 23 241 98 224 203 119 193 109 203 80 119 187 147 59 189 190 220 164 37 39 17 36 63 61 32 230 8 200 129 177 75 134 86 18 5 89 57 242 151 96 82 126 93 10 17 145 70 188 136 31 251 129 59 180 208 232 202 105 159 187 163 154 243 43 152 0 19 120 103 205 186 7 239 34 24 1 14 194 168 134 66 119 219 224 242 38 171 213 36 31 139 197 28 198 24 40 7 128 96 251 56 79 242 234 98 133 224 189 208 140 165 144 145 126 72 224 87 52 147 105 35 185 101 201 197 227 39 73 133 228 231 87 50 94 232 52 73 84 19 150 124 24 11 210 248 3 4 57 51 2 64 188 83 190 134 233 243 200 74 14 234 191 156 62 34 128 225 130 85 168 124 129 42 89 100 65 98 13 172 63 71 69 194 225 192 130 192 99 38 71 175 15 99 12 152 163 39 1 250 222 135 11 104 64 134 10 48 75 252 150 92 248 9 40 232 138 18 90 250 84 175 200 41 89 41 202 111 192 59 23 15 9 4 68 238 35 223 34 32 135 159 243 121 125 187 158 38 94 99 77 53 87 165 85 191 243 54 254 112 151 146 211 98 41 176 1 42 178 156 196 178 44 82 96 117 56 77 248 20 58 246 24 229 239 116 12 152 163 39 193 8 50 155 68 56 206 22 10 62 145 169 196 11 255 54 64 239 75 198 191 8 198 201 157 147 68 201 207 243 93 164 213 79 40 20 174 7 121 241 197 233 173 111 78 217 78 58 221 184 92 37 199 107 213 31 175 123 245 237 113 80 33 156 1 115 200 230 81 9 62 31 152 104 136 5 209 42 196 160 250 36 19 200 8 49 95 147 24 208 74 33 193 98 48 20 86 82 193 26 10 1 97 86 46 43 249 109 18 227 149 65 232 216 132 103 194 206 202 246 99 140 15 94 191 208 76 64 210 49 32 194 249 72 106 125 107 237 90 116 141 117 103 254 155 88 38 218 32 88 8 201 199 119 220 177 0 56 68 210 227 224 120 220 238 136 198 218 136 60 17 140 24 128 96 175 47 123 12 108 55 146 96 231 13 67 31 38 28 29 101 157 0 18 80 63 26 96 200 7 31 1 57 249 253 197 63 26 90 113 12 38 12 81 2 13 104 63 75 42 164 11 57 62 76 143 128 116 254 110 237 171 175 126 173 142 14 20 208 232 238 2 77 18 114 176 95 147 61 174 87 129 28 14 208 37 20 89 23 182 13 140 5 214 70 180 34 174 65 248 28 28 61 9 78 168 221 189 178 242 102 159 239 196 189 43 76 158 10 187 12 2 243 248 178 63 23 86 225 139 226 130 194 11 216 11 175 144 10 233 32 32 185 103 73 102 141 126 165 72 89 52 242 192 28 114 168 241 104 47 194 9 79 165 80 33 137 90 237 39 189 218 142 154 68 100 214 233 180 199 80 232 251 68 248 28 24 0 98 229 249 206 174 240 18 33 227 133 189 185 162 8 211 181 195 73 65 224 181 13 133 48 192 1 70 99 122 201 241 230 19 0 178 148 244 144 142 189 18 28 57 179 70 255 4 58 66 227 35 7 72 171 3 140 71 214 20 18 14 217 122 192 191 17 131 72 108 68 100 173 150 176 60 25 251 163 24 56 6 22 59 207 79 188 18 177 233 25 25 217 123 79 120 37 193 224 138 130 76 10 48 62 209 215 62 1 223 173 132 144 60 76 102 147 140 178 143 197 64 37 237 235 163 71 239 196 214 214 120 121 45 96 172 253 193 184 217 56 80 192 96 148 3 154 68 202 130 182 57 104 16 112 119 179 57 86 99 141 253 81 124 222 5 104 66 8 230 213 11 205 81 16 136 74 203 37 65 32 53 146 76 65 240 161 204 143 203 200 123 31 65 58 237 237 166 191 155 222 146 158 159 79 57 70 47 70 16 101 238 236 145 151 71 174 185 171 16 71 10 208 87 148 91 15 84 133 157 156 235 36 86 111 236 179 44 190 224 86 61 33 132 206 41 41 187 59 10 2 87 172 32 35 45 130 116 100 108 104 4 14 233 66 50 121 103 47 68 235 60 253 77 42 102 139 95 35 32 144 90 90 180 91 136 67 230 34 47 117 226 212 110 64 30 89 105 183 54 70 78 159 197 125 3 15 107 18 66 22 226 1 155 209 244 70 72 202 112 177 16 1 1 251 36 52 210 55 19 0 170 37 140 1 0 239 79 122 31 57 222 61 167 172 246 121 113 152 192 158 173 196 137 66 133 3 158 195 110 183 134 251 53 165 8 246 39 178 55 68 65 64 66 65 168 7 126 98 87 73 44 201 82 0 57 113 156 228 91 247 80 175 36 9 87 232 229 219 193 246 53 102 147 63 34 192 239 95 82 38 188 255 254 187 63 57 135 45 131 85 249 37 152 88 25 175 159 78 20 104 4 99 42 186 223 48 220 12 12 10 66 72 248 19 149 155 163 36 205 32 180 151 74 104 190 181 0 136 68 250 69 126 201 191 169 213 129 143 47 134 75 227 251 79 64 30 157 155 180 3 10 4 172 173 138 206 18 196 119 16 12 90 220 189 40 250 251 154 242 141 63 136 37 32 102 55 238 28 132 138 165 199 195 36 217 141 48 62 53 211 24 149 237 242 29 171 164 49 120 133 227 96 180 238 44 33 28 191 223 57 73 118 226 202 106 45 175 34 183 119 185 93 110 89 107 77 114 117 27 251 13 194 205 163 144 65 108 188 124 132 93 93 217 180 0 54 12 133 2 191 40 71 232 226 146 50 26 130 119 199 131 99 210 170 213 43 127 180 115 241 206 239 29 69 12 53 90 113 192 160 51 30 206 70 160 181 182 200 92 20 193 136 31 65 4 132 236 79 248 220 246 11 228 25 90 123 54 169 227 13 67 193 167 156 167 209 201 143 100 210 81 40 99 86 208 162 231 88 73 4 138 99 12 126 191 159 37 38 214 227 116 80 161 149 39 138 152 142 29 87 130 8 8 114 116 94 60 126 182 185 144 124 59 119 25 105 113 47 156 131 118 254 82 152 131 40 236 232 215 142 226 120 205 170 34 235 14 142 97 113 83 64 10 219 227 113 58 173 22 200 38 252 71 54 30 125 245 186 184 125 169 10 58 187 225 211 206 18 156 206 187 120 222 47 72 231 105 18 173 132 145 232 227 230 140 72 199 131 151 142 210 53 38 220 91 37 170 181 1 217 139 147 133 7 218 15 20 90 179 37 90 220 55 91 95 7 224 126 219 31 38 91 81 178 246 241 165 83 239 4 51 168 90 125 244 181 8 199 251 175 236 160 238 9 47 238 114 185 101 121 114 83 10 168 8 106 63 244 250 222 86 246 22 81 32 136 139 55 180 164 147 117 73 217 68 65 144 26 55 16 65 154 164 228 36 168 133 164 119 55 156 60 121 242 181 247 255 240 196 185 162 48 7 117 79 242 186 67 30 40 80 159 204 102 57 153 250 8 198 45 248 63 9 0 132 7 16 180 191 201 149 21 133 9 47 144 8 124 175 72 201 177 18 218 239 73 47 253 249 165 115 69 69 178 237 160 123 27 226 194 137 15 116 134 41 122 25 192 96 252 75 187 15 16 15 130 200 54 190 228 5 154 73 139 199 147 89 66 146 103 34 226 58 56 31 113 79 196 140 71 79 212 8 222 232 96 116 195 32 48 143 52 46 145 167 17 185 34 222 157 132 79 139 224 218 42 190 138 110 10 212 162 159 165 225 112 202 251 14 51 117 80 189 66 17 254 26 210 173 167 32 91 20 158 255 180 49 153 62 9 164 133 253 135 29 242 211 9 5 20 181 138 53 128 196 230 132 215 177 177 238 169 255 194 190 213 16 114 31 225 133 31 119 101 200 147 30 132 35 1 203 218 199 210 86 237 241 184 220 209 117 172 211 212 11 163 79 19 216 115 155 14 116 118 22 68 183 50 251 36 112 156 124 109 241 19 59 194 67 145 27 29 135 188 41 112 133 215 177 212 61 245 187 240 184 109 24 196 107 89 114 36 31 211 254 163 63 236 252 201 43 71 17 67 89 21 126 60 65 14 10 84 120 85 112 93 28 130 183 49 153 174 3 9 153 88 145 9 168 35 242 36 97 247 118 123 112 182 187 126 85 96 12 222 248 194 35 94 32 193 160 221 64 65 184 106 250 208 139 110 199 77 22 115 244 220 196 125 71 28 65 204 22 147 194 224 99 188 146 63 242 180 200 110 183 152 123 203 147 241 203 161 78 253 131 4 17 196 106 119 120 92 189 159 22 133 167 236 254 139 162 231 203 116 8 136 209 98 49 217 29 116 147 105 115 68 214 177 255 68 157 190 92 16 81 16 189 197 98 53 81 7 229 188 110 184 187 93 238 233 115 130 244 144 139 234 193 114 88 172 228 244 150 167 47 99 93 247 3 66 252 17 4 5 124 184 37 82 224 193 65 134 65 31 134 134 232 20 113 237 22 112 208 48 68 159 179 83 219 218 123 149 57 88 0 122 127 243 33 20 253 127 1 190 52 230 233 139 128 244 196 117 117 118 43 65 122 6 59 70 236 247 181 6 53 70 79 207 63 4 24 0 133 51 241 30 228 174 147 219 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WAHandlerEditorFiles methodsFor: 'accessing-files' stamp: 'lr 5/22/2007 21:52'!
savePng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 0 0 0 0 0 249 67 187 127 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 10 13 55 15 158 42 216 191 0 0 0 140 116 69 88 116 67 111 109 109 101 110 116 0 77 101 110 117 45 115 105 122 101 100 32 105 99 111 110 10 61 61 61 61 61 61 61 61 61 61 10 10 40 99 41 32 50 48 48 51 32 74 97 107 117 98 32 39 106 105 109 109 97 99 39 32 83 116 101 105 110 101 114 44 32 10 104 116 116 112 58 47 47 106 105 109 109 97 99 46 109 117 115 105 99 104 97 108 108 46 99 122 10 10 99 114 101 97 116 101 100 32 119 105 116 104 32 116 104 101 32 71 73 77 80 44 10 104 116 116 112 58 47 47 119 119 119 46 103 105 109 112 46 111 114 103 103 138 199 71 0 0 2 132 73 68 65 84 56 203 157 146 77 72 84 97 20 134 159 185 221 241 230 207 228 76 224 181 49 205 145 178 81 108 81 81 52 38 20 184 200 22 69 20 46 66 40 44 130 138 169 193 86 45 42 202 69 17 84 16 6 82 180 40 10 34 176 40 40 106 91 208 34 137 68 138 166 69 153 84 106 134 164 232 220 155 206 253 249 78 11 97 108 178 54 189 155 243 193 225 60 156 247 61 95 224 200 217 227 39 63 91 21 218 216 184 51 9 84 1 91 129 134 160 38 217 208 194 159 63 22 25 206 205 187 231 207 157 224 31 10 52 119 116 237 141 173 172 143 85 151 155 131 171 107 202 58 170 35 133 107 109 207 39 253 45 195 235 222 231 234 195 215 81 226 145 55 203 186 59 239 12 255 21 144 60 125 190 219 157 26 59 236 137 198 168 31 102 218 40 99 129 30 164 173 101 35 203 43 22 115 249 254 11 252 161 62 98 5 227 127 155 239 36 121 44 37 95 70 6 68 68 100 224 115 90 122 211 3 146 186 246 68 18 7 47 72 207 171 47 210 245 244 173 180 158 186 46 239 6 135 229 119 89 150 37 169 142 164 232 134 238 179 180 60 198 196 196 4 225 146 114 180 192 36 133 226 0 208 247 113 20 179 68 231 251 120 134 247 3 159 88 178 168 16 2 0 66 65 65 1 0 186 231 130 40 193 87 138 237 39 110 204 219 177 119 112 2 215 243 185 216 243 146 139 61 47 1 120 124 118 31 200 108 95 3 80 162 80 190 162 235 80 35 0 237 187 119 210 152 88 199 204 140 77 52 164 209 148 88 207 222 214 237 0 236 105 94 129 242 21 34 50 7 16 17 34 145 48 21 101 49 46 29 88 199 205 187 15 136 199 170 208 8 160 17 32 81 95 205 173 123 143 104 219 92 195 142 166 245 20 21 23 229 3 0 44 203 194 52 77 170 163 181 57 72 227 170 229 212 198 42 185 124 251 33 109 155 107 216 181 41 129 105 154 56 142 147 179 168 3 40 165 176 109 27 0 211 52 49 77 147 238 163 133 28 187 218 67 214 245 217 223 82 79 251 182 45 104 154 198 212 212 20 182 109 19 10 133 230 0 134 97 80 89 89 153 23 222 154 134 13 60 187 178 1 0 219 182 113 28 135 233 233 233 121 33 235 0 253 253 253 184 174 155 215 240 60 15 93 215 115 239 63 21 137 68 242 51 240 60 143 116 58 205 200 200 8 153 76 6 17 65 68 48 12 131 161 161 33 66 161 80 174 90 150 133 101 89 249 87 80 74 81 92 92 68 48 24 204 125 18 0 215 117 17 53 11 19 53 123 62 229 251 249 22 194 225 48 165 165 165 68 163 81 0 178 217 44 64 46 237 120 93 28 165 20 241 186 58 148 82 44 137 70 115 150 3 169 142 228 25 224 52 255 167 206 95 147 59 51 76 213 34 98 109 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WAHandlerEditorFiles methodsFor: 'accessing' stamp: 'lr 12/29/2008 09:49'!
selectorsToInclude
	^ #( faviconIco handlerCss handlerJs )! !

!WAFileHandler methodsFor: '*seaside-development' stamp: 'lr 2/10/2008 15:45'!
configurationComponent
	^ WAFileHandlerEditor on: self! !

WAPainter subclass: #WAPlugin
	instanceVariableNames: 'target requestor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAPlugin commentStamp: 'lr 5/30/2007 22:18' prior: 0!
I am an abstract root class for all plugins. Plugins are an easy way to add or remove additional tools without changing the codebase. To add a new plugin make sure you choose the right superclass so that the tool can detect your code.

The appearance of all plugins, such as icons, has to be configured using CSS.!

WAPlugin subclass: #WADispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WADispatcherPlugin commentStamp: 'pmm 5/27/2007 07:34' prior: 0!
Abstract root class for all plugins that add an action for an application to the dispatcher editor.!

WADispatcherPlugin subclass: #WAConfigureDispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAConfigureDispatcherPlugin commentStamp: 'pmm 5/28/2007 23:07' prior: 0!
I display the configuration dialog of an application. See WAApplication >> #configurationComponent!

!WAConfigureDispatcherPlugin methodsFor: 'actions' stamp: 'lr 11/28/2008 16:47'!
execute
	self requestor show: self target configurationComponent! !

!WAConfigureDispatcherPlugin methodsFor: 'testing' stamp: 'lr 5/11/2007 14:03'!
isActive
	^ self target configurationComponent notNil! !

!WAConfigureDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:02'!
label
	^ 'Configure'! !

!WAConfigureDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:10'!
priority
	^ 100! !

WADispatcherPlugin subclass: #WACopyDispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WACopyDispatcherPlugin commentStamp: 'pmm 5/28/2007 23:06' prior: 0!
I make a copy of an application.!

!WACopyDispatcherPlugin methodsFor: 'actions' stamp: 'jf 10/7/2008 01:17'!
execute
	| name |
	name := self requestor
		request: 'Name'
		label: 'add'
		default: self target name.
	name ifNil: [ ^ self ].
	self requestor handler
		register: (self target cloneHandler
			setName: name;
			yourself)! !

!WACopyDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:02'!
label
	^ 'Copy'! !

!WACopyDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:11'!
priority
	^ 200! !

WADispatcherPlugin subclass: #WARemoveDispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WARemoveDispatcherPlugin commentStamp: 'pmm 5/28/2007 23:06' prior: 0!
I remove an application.!

!WARemoveDispatcherPlugin methodsFor: 'actions' stamp: 'lr 2/10/2008 17:23'!
execute
	self requestor handler unregister: self target! !

!WARemoveDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:02'!
label
	^ 'Remove'! !

!WARemoveDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:11'!
priority
	^ 300! !

WAPlugin subclass: #WAHaloPlugin
	instanceVariableNames: ''
	classVariableNames: 'EnableSeasideTools'
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAHaloPlugin commentStamp: 'pmm 5/27/2007 07:47' prior: 0!
Abstract root class for all halo tools. They add functionality to the halo toolbar.!

WAHaloPlugin subclass: #WAClassnameHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAClassnameHaloPlugin commentStamp: 'pmm 5/27/2007 17:34' prior: 0!
I display the class name of the component class.!

!WAClassnameHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 100! !

!WAClassnameHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:58'!
renderContentOn: html
	html div class: self cssClass; with: self target className! !

!WAHaloPlugin class methodsFor: 'initialization' stamp: 'lr 5/11/2007 01:22'!
initialize
	EnableSeasideTools := true! !

!WAHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 12:22'!
renderContentOn: html
	html div
		class: self cssClass;
		with: [ super renderContentOn: html ]! !

WAHaloPlugin subclass: #WAModeHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAModeHaloPlugin commentStamp: 'pmm 5/27/2007 17:35' prior: 0!
I control the rendering modes of the halo.!

!WAModeHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 900! !

!WAModeHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:58'!
renderContentOn: html
	html div class: self cssClass; with: [
		html text: '['.
		self requestor modes
			do: [ :each |
				html anchor
					class: 'active' if: self requestor mode = each;
					title: (self labelForSelector: each allButLast);
					callback: [ self requestor mode: each ];
					with: each first asUppercase ]
			separatedBy: [ html text: '|' ].
		html text: ']' ]! !

WAHaloPlugin subclass: #WAStylesHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAStylesHaloPlugin commentStamp: 'pmm 5/27/2007 17:35' prior: 0!
I open the style editor on the component class.!

!WAStylesHaloPlugin methodsFor: 'actions' stamp: 'pmm 11/14/2008 22:26'!
execute
	EnableSeasideTools
		ifTrue: [ self open: (WAPluggableTool on: (WAViewer on: self target)) ]
		ifFalse: [ Browser fullOnClass: self target class selector: #style ]! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:56'!
label
	^ 'Styles'! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 700! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'pmm 5/16/2007 16:24'!
tooltip
	^ 'CSS Style Editor'! !

!WAPlugin class methodsFor: 'instance-creation' stamp: 'lr 5/11/2007 14:18'!
allSubclassesOn: aTargetObject for: aRequestorObject
	| plugins |
	plugins := self allSubclasses
		collect: [ :each | each on: aTargetObject for: aRequestorObject ].
	^ plugins asSortedCollection! !

!WAPlugin class methodsFor: 'instance-creation' stamp: 'lr 5/11/2007 13:50'!
on: aTargetObject for: aRequestorObject
	^ self basicNew initializeTarget: aTargetObject requestor: aRequestorObject! !

!WAPlugin methodsFor: 'comparing' stamp: 'lr 5/11/2007 10:51'!
<= aPlugin
	^ self priority <= aPlugin priority! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 9/25/2008 17:56'!
cssClass
	"Answer a CSS class that will be applied to an automatically rendered link."

	^ (self class name allButFirst: 2) asLowercase! !

!WAPlugin methodsFor: 'actions' stamp: 'lr 5/11/2007 10:50'!
execute
	"Execute the receiving plugin."! !

!WAPlugin methodsFor: 'initialization' stamp: 'lr 5/11/2007 13:50'!
initializeTarget: aTargetObject requestor: aRequestorObject
	target := aTargetObject.
	requestor := aRequestorObject! !

!WAPlugin methodsFor: 'testing' stamp: 'lr 10/28/2007 14:42'!
isActive
	"Answer wheter the plugin is usable with the current target."

	^ true! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
label
	"Answer the menu label of the plugin."

	^ self printString! !

!WAPlugin methodsFor: 'actions' stamp: 'jf 10/19/2008 15:47'!
open: aComponent
	"Replace the current page with aComponent."

	self session inNewRenderLoopCall:
		(aComponent
			addDecoration: (WAWindowDecoration new
				cssClass: self cssClass;
				title: self label;
				yourself);
			yourself)! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
priority
	"Answer a number used to sort the receiver. A lower number means it appears earlier on."

	^ 0! !

!WAPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	"A default render method to display the interface of the receiving plugin. Might be overriden with specific behavior in subclasses."

	html anchor
		title: self tooltip;
		class: self cssClass;
		callback: [ self execute ];
		with: self label! !

!WAPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 12:02'!
rendererClass
	^ WARenderCanvas! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
requestor
	"Answer the requestor component the plugin is working on."

	^ requestor! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
target
	"Answer the target object the plugin is working on."

	^ target! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
tooltip
	"Answer a tooltip string that is displayed on the plugin link or button."

	^ nil! !

WAPlugin subclass: #WAToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAToolPlugin commentStamp: 'pmm 5/27/2007 07:47' prior: 0!
Abstract root class for all development tool bar tools.!

WAToolPlugin subclass: #WAConfigureToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAConfigureToolPlugin commentStamp: 'pmm 5/27/2007 18:33' prior: 0!
I display the configuration dialog for the currently active application!

!WAConfigureToolPlugin methodsFor: 'actions' stamp: 'pmm 11/14/2008 22:26'!
execute
	self open: (WAPluggableTool on: self application configurationComponent)! !

!WAConfigureToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:16'!
label
	^ 'Configure'! !

!WAConfigureToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 200! !

WAToolPlugin subclass: #WADeprecationToolPlugin
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WADeprecationToolPlugin commentStamp: 'pmm 5/27/2007 18:33' prior: 0!
I display deprecation warnings.!

!WADeprecationToolPlugin methodsFor: 'actions' stamp: 'pmm 10/11/2008 18:27'!
execute
	self open: (WADeprecation on: filter)! !

!WADeprecationToolPlugin methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:24'!
initializeTarget: aTargetObject requestor: aRequestorObject
	super initializeTarget: aTargetObject requestor: aRequestorObject.
	self session addFilter: (filter := WADeprecatedToolFilter new)! !

!WADeprecationToolPlugin methodsFor: 'testing' stamp: 'lr 9/25/2008 15:14'!
isActive
	^ filter notifications notEmpty! !

!WADeprecationToolPlugin methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:41'!
label
	^ 'Deprecated (' , filter notifications size printString , ')'! !

!WADeprecationToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 700! !

WAToolPlugin subclass: #WANewSessionToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WANewSessionToolPlugin commentStamp: 'pmm 5/27/2007 18:32' prior: 0!
I create a new session.!

!WANewSessionToolPlugin class methodsFor: 'accessing' stamp: 'pmm 5/10/2007 22:18'!
title
	^'New Session'! !

!WANewSessionToolPlugin methodsFor: 'actions' stamp: 'jf 10/18/2008 17:39'!
execute
	self session unregister.
	self requestContext redirectTo: self application baseUrl! !

!WANewSessionToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:26'!
label
	^ 'New Session'! !

!WANewSessionToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 100! !

WAToolPlugin subclass: #WATerminateToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WATerminateToolPlugin commentStamp: 'pmm 5/27/2007 18:32' prior: 0!
I try to terminate the process handling this session. This can work of you're at 100% CPU.!

!WATerminateToolPlugin methodsFor: 'testing' stamp: 'jf 9/11/2008 14:55'!
isActive
	^ self session sessionAllowTermination! !

!WATerminateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:29'!
label
	^ 'Terminate'! !

!WATerminateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:57'!
priority
	^ 600! !

!WATerminateToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html anchor
		url: (html context actionUrl
			withParameter: 'terminate');
		with: self label! !

WAToolPlugin subclass: #WATimingToolPlugin
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WATimingToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I display render and callback times.!

!WATimingToolPlugin methodsFor: 'initialization' stamp: 'lr 9/25/2008 10:46'!
initializeTarget: aTargetObject requestor: aRequestorObject
	super initializeTarget: aTargetObject requestor: aRequestorObject.
	self session addFilter: (filter := WATimingToolFilter new)! !

!WATimingToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 900! !

!WATimingToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html span
		title: 'Callback Time';
		with: filter previousTiming.
	html text: '/'.
	html span
		title: 'Render Time';
		with: filter currentTiming.
	html text: ' ms'! !

WAToolPlugin subclass: #WAToggleHalosToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAToggleHalosToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I toggle halos on and off.!

!WAToggleHalosToolPlugin methodsFor: 'actions' stamp: 'lr 5/11/2007 13:54'!
execute
	 self requestor toggleHalos! !

!WAToggleHalosToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
label
	^ 'Toggle Halos'! !

!WAToggleHalosToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 300! !

WAToolPlugin subclass: #WAValidateToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAValidateToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I validate and XHTML page by sending it to the W3C validator. I only work if the website is publically available.!

!WAValidateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:30'!
label
	^ 'XHTML'! !

!WAValidateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 800! !

!WAValidateToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html anchor
		title: 'Validate XHTML';
		url: 'http://validator.w3.org/check/referer';
		with: self label! !

!WAUserConfiguration methodsFor: '*seaside-development' stamp: 'jf 7/21/2008 23:53'!
configurationComponent
	^ WAUserConfigurationEditor on: self! !
WAHalo initialize!
WADispatcherEditor initialize!
WADispatcherViewer initialize!
WAHaloPlugin initialize!
